@@ -3,13 +3,12 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef KEYFRAMELISTMODEL_H
-#define KEYFRAMELISTMODEL_H
+#pragma once
 
 #include "assets/model/assetparametermodel.hpp"
 #include "definitions.h"
-#include "utils/gentime.h"
 #include "undohelper.hpp"
+#include "utils/gentime.h"
 
 #include <QAbstractListModel>
 #include <QReadWriteLock>
@@ -21,7 +20,6 @@ class AssetParameterModel;
 class DocUndoStack;
 class EffectItemModel;
 
-
 enum class KeyframeType { Linear = mlt_keyframe_linear, Discrete = mlt_keyframe_discrete, Curve = mlt_keyframe_smooth };
 Q_DECLARE_METATYPE(KeyframeType)
 using Keyframe = std::pair<GenTime, KeyframeType>;
@@ -209,7 +207,7 @@ private:
 
 signals:
     void modelChanged();
-    void requestModelUpdate(const QModelIndex &, const QModelIndex &, const QVector<int>&);
+    void requestModelUpdate(const QModelIndex &, const QModelIndex &, const QVector<int> &);
 
 public:
     // this is to enable for range loops
@@ -217,5 +215,3 @@ public:
     auto end() -> decltype(m_keyframeList.end()) { return m_keyframeList.end(); }
 };
 // Q_DECLARE_METATYPE(KeyframeModel *)
-
-#endif
