@@ -8,19 +8,14 @@
 #include "core.h"
 #include "mainwindow.h"
 
+#include <QDir>
 #include <QDomDocument>
 #include <QDomElement>
 #include <QStandardPaths>
-#include <QDir>
 
 #include <kio_version.h>
-#if KIO_VERSION > QT_VERSION_CHECK(5, 70, 0)
-#include <KIO/OpenUrlJob>
 #include <KIO/JobUiDelegate>
-#else
-#include <KRun>
-#endif
-
+#include <KIO/OpenUrlJob>
 
 ListDependencyParamWidget::ListDependencyParamWidget(std::shared_ptr<AssetParameterModel> model, QModelIndex index, QWidget *parent)
     : AbstractParamWidget(std::move(model), index, parent)
@@ -34,15 +29,11 @@ ListDependencyParamWidget::ListDependencyParamWidget(std::shared_ptr<AssetParame
     setToolTip(comment);
     m_infoMessage->hide();
     connect(m_infoMessage, &KMessageWidget::linkActivated, this, [this](const QString &contents) {
-#if KIO_VERSION > QT_VERSION_CHECK(5, 70, 0)
         auto *job = new KIO::OpenUrlJob(QUrl(contents));
         job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
         // methods like setRunExecutables, setSuggestedFilename, setEnableExternalBrowser, setFollowRedirections
         // exist in both classes
         job->start();
-#else
-        new KRun(QUrl(contents), this);
-#endif
     });
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
     m_list->setIconSize(QSize(50, 30));
@@ -73,11 +64,10 @@ ListDependencyParamWidget::ListDependencyParamWidget(std::shared_ptr<AssetParame
     slotRefresh();
 
     // emit the signal of the base class when appropriate
-    connect(this->m_list, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
-            this, [this](int) {
-                const QString val = m_list->itemData(m_list->currentIndex()).toString();
-                emit valueChanged(m_index, val, true);
-                checkDependencies(val);
+    connect(this->m_list, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, [this](int) {
+        const QString val = m_list->itemData(m_list->currentIndex()).toString();
+        emit valueChanged(m_index, val, true);
+        checkDependencies(val);
     });
 }
 
@@ -106,9 +96,7 @@ void ListDependencyParamWidget::setIconSize(const QSize &size)
     m_list->setIconSize(size);
 }
 
-void ListDependencyParamWidget::slotShowComment(bool /*show*/)
-{
-}
+void ListDependencyParamWidget::slotShowComment(bool /*show*/) {}
 
 QString ListDependencyParamWidget::getValue()
 {
@@ -195,7 +183,7 @@ void ListDependencyParamWidget::slotRefresh()
         }
         if (!value.isEmpty()) {
             int ix = m_list->findData(value);
-            if (ix > -1)  {
+            if (ix > -1) {
                 m_list->setCurrentIndex(ix);
             }
         }
