@@ -3,8 +3,7 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef MIXERMANGER_H
-#define MIXERMANGER_H
+#pragma once
 
 #include "definitions.h"
 #include <memory>
@@ -13,7 +12,7 @@
 #include <QWidget>
 
 namespace Mlt {
-    class Tractor;
+class Tractor;
 }
 
 class MixerWidget;
@@ -41,6 +40,10 @@ public:
     void unsetModel();
     /** @brief Some features rely on a specific version of MLT's audiolevel filter, so check it */
     void checkAudioLevelVersion();
+    /** @brief Enable/disable audio monitoring on a track */
+    void monitorAudio(int tid, bool monitor);
+    /** @brief Track currently monitored that will be used for recording */
+    int recordTrack() const;
 
 public slots:
     void recordStateChanged(int tid, bool recording);
@@ -50,7 +53,6 @@ private slots:
 
 signals:
     void updateLevels(int);
-    void recordAudio(int tid);
     void purgeCache();
     void clearMixers();
     void updateRecVolume();
@@ -70,11 +72,8 @@ private:
     QScrollArea *m_channelsBox;
     bool m_visibleMixerManager;
     int m_expandedWidth;
-    QVector <int> m_soloMuted;
+    QVector<int> m_soloMuted;
     int m_recommendedWidth;
+    int m_monitorTrack;
     bool m_filterIsV2;
-
 };
-
-#endif
-
