@@ -6,8 +6,7 @@ This file is part of Kdenlive. See www.kdenlive.org.
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef PROJECTCLIP_H
-#define PROJECTCLIP_H
+#pragma once
 
 #include "abstractprojectitem.h"
 #include "definitions.h"
@@ -153,13 +152,12 @@ public:
     QString getToolTip() const override;
 
     /** @brief The clip hash created from the clip's resource. */
-    const QString hash();
+    const QString hash(bool createIfEmpty = true);
+    /** @brief The clip hash created from the clip's resource, plus the video stream in case of multi-stream clips. */
+    const QString hashForThumbs();
     /** @brief Callculate a file hash from a path. */
     static const QPair<QByteArray, qint64> calculateHash(const QString &path);
 
-    /** @brief Returns true if we are using a proxy for this clip. */
-    bool hasProxy() const;
-
     /** Cache for every audio Frame with 10 Bytes */
     /** format is frame -> channel ->bytes */
     bool audioThumbCreated() const;
@@ -345,5 +343,3 @@ signals:
     void boundsChanged(QVector <QPoint>bounds);
     void registeredClipChanged();
 };
-
-#endif
