@@ -5,27 +5,49 @@ This file is part of Kdenlive. See www.kdenlive.org.
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef MEDIACAPTURE_H
-#define MEDIACAPTURE_H
+#pragma once
 
 #include <QAudioBuffer>
+#include <QAudioInput>
 #include <QAudioRecorder>
 #include <QCamera>
+#include <QElapsedTimer>
+#include <QIODevice>
 #include <QMediaRecorder>
-#include <QStringList>
-#include <QUrl>
-#include <QTimer>
 #include <QMutex>
+#include <QStringList>
+#include <QTimer>
+#include <QUrl>
 #include <memory>
 
 class QAudioRecorder;
 class QAudioProbe;
 
+
+class AudioDevInfo: public QIODevice
+{
+    Q_OBJECT
+public:
+    AudioDevInfo(const QAudioFormat &format, QObject *parent = nullptr);
+    quint32 maxAmplitude = 0;
+
+signals:
+    void levelChanged(const QVector<qreal> &dbLevels);
+    void levelRecChanged(const QVector<qreal> &dbLevels);
+
+protected:
+    qint64 readData(char *data, qint64 maxSize) override;
+    qint64 writeData(const char *data, qint64 maxSize) override;
+private:
+    const QAudioFormat m_format;
+};
+
 class MediaCapture : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(QVector<qreal> levels READ levels NOTIFY levelsChanged)
     Q_PROPERTY(int recordState READ recordState NOTIFY recordStateChanged)
+    Q_PROPERTY(int recDuration MEMBER m_lastPos NOTIFY recDurationChanged)
 
 public:
     MediaCapture(QObject *parent);
@@ -47,6 +69,16 @@ public:
     int currentState;
     Q_INVOKABLE QVector<qreal> levels() const;
     Q_INVOKABLE int recordState() const;
+    void switchMonitorState(bool run);
+    /** @brief Returns true is audio monitoring is currently in progress **/
+    bool isMonitoring() const;
+    const QVector<double> recLevels() const;
+    /** @brief Start monitoring a track **/
+    Q_INVOKABLE void switchMonitorState(int tid, bool run);
+    void pauseRecording();
+    void resumeRecording();
+    /** @brief Start the real audio capture **/
+    int startCapture();
 
 public slots:
     void displayErrorMessage();
@@ -55,18 +87,25 @@ public slots:
 
 private:
     std::unique_ptr<QAudioRecorder> m_audioRecorder;
+    std::unique_ptr<QAudioInput> m_audioInput;
+    QScopedPointer<AudioDevInfo> m_audioInfo;
     std::unique_ptr<QMediaRecorder> m_videoRecorder;
     std::unique_ptr<QCamera> m_camera;
-    std::unique_ptr<QAudioProbe> m_probe;
+    QElapsedTimer m_recTimer;
     QString m_audioDevice;
     QUrl m_path;
     QVector<qreal> m_levels;
+    QVector<double> m_recLevels;
     int m_recordState;
+    /** @brief Duration of the recording */
+    int m_lastPos;
+    int m_tid;
+    /** @brief true if we started the record countdown */
+    bool m_readyForRecord;
     QTimer m_resetTimer;
     QMutex m_recMutex;
 
 private slots:
-    void processBuffer(const QAudioBuffer &buffer);
     void resetIfUnused();
 
 signals:
@@ -74,6 +113,5 @@ signals:
     void recordStateChanged(int tid, bool recording);
     void recordDone();
     void audioLevels(QVector<qreal> levels);
+    void recDurationChanged();
 };
-
-#endif
