@@ -12,35 +12,37 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "bin/projectclip.h"
 #include "bin/projectitemmodel.h"
 #include "core.h"
-#include "definitions.h"
 #include "doc/docundostack.hpp"
 #include "doc/kdenlivedoc.h"
 #include "kdenlive_debug.h"
 #include "kdenlivesettings.h"
 #include "project/dialogs/slideshowclip.h"
-#include "timecodedisplay.h"
 #include "titler/titlewidget.h"
 #include "titletemplatedialog.h"
 #include "ui_colorclip_ui.h"
 #include "ui_qtextclip_ui.h"
 #include "utils/devices.hpp"
+#include "widgets/timecodedisplay.h"
 #include "xml/xml.hpp"
 
-#include "klocalizedstring.h"
+#include <KDirOperator>
 #include <KFileWidget>
+#include <KIO/RenameDialog>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KRecentDirs>
 #include <KWindowConfig>
-#include <KDirOperator>
 
 #include <QDialog>
 #include <QDir>
 #include <QMimeDatabase>
 #include <QPointer>
+#include <QProcess>
 #include <QPushButton>
 #include <QStandardPaths>
 #include <QUndoCommand>
 #include <QWindow>
+
 #include <unordered_map>
 #include <utility>
 
@@ -67,7 +69,15 @@ QStringList ClipCreationDialog::getExtensions()
     mimeTypes << QStringLiteral("image/gif") << QStringLiteral("image/jpeg") << QStringLiteral("image/png") << QStringLiteral("image/x-tga")
               << QStringLiteral("image/x-bmp") << QStringLiteral("image/svg+xml") << QStringLiteral("image/tiff") << QStringLiteral("image/x-xcf")
               << QStringLiteral("image/x-xcf-gimp") << QStringLiteral("image/x-vnd.adobe.photoshop") << QStringLiteral("image/x-pcx")
-              << QStringLiteral("image/x-exr") << QStringLiteral("image/x-portable-pixmap") << QStringLiteral("application/x-krita") << QStringLiteral("image/webp");
+              << QStringLiteral("image/x-exr") << QStringLiteral("image/x-portable-pixmap") << QStringLiteral("application/x-krita")
+              << QStringLiteral("image/webp") << QStringLiteral("image/jp2") << QStringLiteral("image/avif") << QStringLiteral("image/heif")
+              << QStringLiteral("image/jxl");
+
+    // Lottie animations
+    bool allowLottie = KdenliveSettings::producerslist().contains(QLatin1String("glaxnimate"));
+    if (allowLottie) {
+        mimeTypes << QStringLiteral("application/json");
+    }
 
     QMimeDatabase db;
     QStringList allExtensions;
@@ -77,12 +87,11 @@ QStringList ClipCreationDialog::getExtensions()
             allExtensions.append(mime.globPatterns());
         }
     }
+    if (allowLottie) {
+        allExtensions.append(QStringLiteral("*.rawr"));
+    }
     // process custom user extensions
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList customs = KdenliveSettings::addedExtensions().split(' ', QString::SkipEmptyParts);
-#else
     const QStringList customs = KdenliveSettings::addedExtensions().split(' ', Qt::SkipEmptyParts);
-#endif
     if (!customs.isEmpty()) {
         for (const QString &ext : customs) {
             if (ext.startsWith(QLatin1String("*."))) {
@@ -101,7 +110,7 @@ QStringList ClipCreationDialog::getExtensions()
     return allExtensions;
 }
 
-QString ClipCreationDialog::getExtensionsFilter(const QStringList& additionalFilters)
+QString ClipCreationDialog::getExtensionsFilter(const QStringList &additionalFilters)
 {
     const QString allExtensions = ClipCreationDialog::getExtensions().join(QLatin1Char(' '));
     QString filter = i18n("All Supported Files") + " (" + allExtensions + ')';
@@ -118,7 +127,7 @@ void ClipCreationDialog::createColorClip(KdenliveDoc *doc, const QString &parent
     QScopedPointer<QDialog> dia(new QDialog(qApp->activeWindow()));
     Ui::ColorClip_UI dia_ui;
     dia_ui.setupUi(dia.data());
-    dia->setWindowTitle(i18n("Color Clip"));
+    dia->setWindowTitle(i18nc("@title:window", "Color Clip"));
     dia_ui.clip_name->setText(i18n("Color Clip"));
 
     QScopedPointer<TimecodeDisplay> t(new TimecodeDisplay(doc->timecode(), dia.get()));
@@ -137,6 +146,98 @@ void ClipCreationDialog::createColorClip(KdenliveDoc *doc, const QString &parent
     }
 }
 
+void ClipCreationDialog::createAnimationClip(KdenliveDoc *doc, const QString &parentId)
+{
+    if (KdenliveSettings::glaxnimatePath().isEmpty()) {
+        KMessageBox::sorry(QApplication::activeWindow(), i18n("Please install Glaxnimate to edit Lottie animations."));
+        return;
+    }
+    QDir dir(doc->projectDataFolder());
+    QString fileName("animation-0001.json");
+    if (dir.cd("animations")) {
+        int ix = 2;
+        while (dir.exists(fileName) && ix < 9999) {
+            QString number = QString::number(ix).rightJustified(4, '0');
+            number.prepend(QStringLiteral("animation-"));
+            number.append(QStringLiteral(".json"));
+            fileName = number;
+            ix++;
+        }
+    } else {
+        dir.mkpath("animations");
+        dir.cd("animations");
+    }
+    QDialog d(QApplication::activeWindow());
+    d.setWindowTitle(i18n("Create animation"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    auto *l = new QVBoxLayout;
+    d.setLayout(l);
+    KUrlRequester fileUrl(&d);
+    ;
+    fileUrl.setMode(KFile::File);
+    fileUrl.setUrl(QUrl::fromLocalFile(dir.absoluteFilePath(fileName)));
+    l->addWidget(new QLabel(i18n("Save animation as"), &d));
+    l->addWidget(&fileUrl);
+    QHBoxLayout *lay = new QHBoxLayout;
+    lay->addWidget(new QLabel(i18n("Animation duration"), &d));
+    TimecodeDisplay tCode(pCore->timecode(), &d);
+    tCode.setValue(QStringLiteral("00:00:05:00"));
+    lay->addWidget(&tCode);
+    l->addLayout(lay);
+    l->addWidget(buttonBox);
+    d.connect(buttonBox, &QDialogButtonBox::rejected, &d, &QDialog::reject);
+    d.connect(buttonBox, &QDialogButtonBox::accepted, &d, &QDialog::accept);
+    if (d.exec() != QDialog::Accepted) {
+        return;
+    }
+    fileName = fileUrl.url().toLocalFile();
+    if (QFile::exists(fileName)) {
+        KIO::RenameDialog renameDialog(QApplication::activeWindow(), i18n("File already exists"), fileUrl.url(), fileUrl.url(),
+                                       KIO::RenameDialog_Option::RenameDialog_Overwrite);
+        if (renameDialog.exec() != QDialog::Rejected) {
+            QUrl final = renameDialog.newDestUrl();
+            if (final.isValid()) {
+                fileName = final.toLocalFile();
+            }
+        } else {
+            return;
+        }
+    }
+    int frameLength = tCode.getValue() - 1;
+    // Params: duration, framerate, width, height
+    const QString templateJson =
+        QString("{\"v\":\"5.7.1\",\"ip\":0,\"op\":%1,\"nm\":\"Animation\",\"mn\":\"{c9eac49f-b1f0-482f-a8d8-302293bd1e46}\",\"fr\":%2,\"w\":%3,\"h\":%4,"
+                "\"assets\":[],\"layers\":[{\"ddd\":0,\"ty\":3,\"ind\":0,\"st\":0,\"ip\":0,\"op\":90,\"nm\":\"Layer\",\"mn\":\"{4d7c9721-b5ef-4075-a89c-"
+                "c4c5629423db}\",\"ks\":{\"a\":{\"a\":0,\"k\":[960,540]},\"p\":{\"a\":0,\"k\":[960,540]},\"s\":{\"a\":0,\"k\":[100,100]},\"r\":{\"a\":0,\"k\":"
+                "0},\"o\":{\"a\":0,\"k\":100}}}],\"meta\":{\"g\":\"Glaxnimate 0.5.0-52-g36d6269d\"}}")
+            .arg(frameLength)
+            .arg(QString::number(doc->timecode().fps()))
+            .arg(pCore->getCurrentFrameSize().width())
+            .arg(pCore->getCurrentFrameSize().height());
+    QFile file(fileName);
+    file.open(QIODevice::WriteOnly | QIODevice::Text);
+    QTextStream out(&file);
+    out << templateJson;
+    file.close();
+    QProcess::startDetached(KdenliveSettings::glaxnimatePath(), {fileName});
+    // Add clip to project
+    QDomDocument xml;
+    QDomElement prod = xml.createElement(QStringLiteral("producer"));
+    xml.appendChild(prod);
+    prod.setAttribute(QStringLiteral("type"), int(ClipType::Animation));
+    int id = pCore->projectItemModel()->getFreeClipId();
+    prod.setAttribute(QStringLiteral("id"), QString::number(id));
+    QMap<QString, QString> properties;
+    if (!parentId.isEmpty()) {
+        properties.insert(QStringLiteral("kdenlive:folderid"), parentId);
+    }
+    properties.insert(QStringLiteral("mlt_service"), QStringLiteral("glaxnimate"));
+    properties.insert(QStringLiteral("resource"), fileName);
+    Xml::addXmlProperties(prod, properties);
+    QString clipId = QString::number(id);
+    pCore->projectItemModel()->requestAddBinClip(clipId, xml.documentElement(), parentId, i18n("Create Animation clip"));
+}
+
 void ClipCreationDialog::createQTextClip(KdenliveDoc *doc, const QString &parentId, Bin *bin, ProjectClip *clip)
 {
     KSharedConfigPtr config = KSharedConfig::openConfig();
@@ -144,7 +245,7 @@ void ClipCreationDialog::createQTextClip(KdenliveDoc *doc, const QString &parent
     QScopedPointer<QDialog> dia(new QDialog(bin));
     Ui::QTextClip_UI dia_ui;
     dia_ui.setupUi(dia.data());
-    dia->setWindowTitle(i18n("Text Clip"));
+    dia->setWindowTitle(i18nc("@title:window", "Text Clip"));
     dia_ui.fgColor->setAlphaChannelEnabled(true);
     dia_ui.lineColor->setAlphaChannelEnabled(true);
     dia_ui.bgColor->setAlphaChannelEnabled(true);
@@ -237,6 +338,7 @@ void ClipCreationDialog::createSlideshowClip(KdenliveDoc *doc, const QString &pa
     if (dia->exec() == QDialog::Accepted) {
         // Ready, create xml
         KRecentDirs::add(QStringLiteral(":KdenliveSlideShowFolder"), QUrl::fromLocalFile(dia->selectedPath()).adjusted(QUrl::RemoveFilename).toLocalFile());
+        KdenliveSettings::setSlideshowmimeextension(dia->extension());
         std::unordered_map<QString, QString> properties;
         properties[QStringLiteral("ttl")] = QString::number(doc->getFramePos(dia->clipDuration()));
         properties[QStringLiteral("loop")] = QString::number(static_cast<int>(dia->loop()));
@@ -246,6 +348,7 @@ void ClipCreationDialog::createSlideshowClip(KdenliveDoc *doc, const QString &pa
         properties[QStringLiteral("luma_file")] = dia->lumaFile();
         properties[QStringLiteral("softness")] = QString::number(dia->softness());
         properties[QStringLiteral("animation")] = dia->animation();
+        properties[QStringLiteral("low-pass")] = QString::number(dia->lowPass());
 
         int duration = doc->getFramePos(dia->clipDuration()) * dia->imageCount();
         ClipCreator::createSlideshowClip(dia->selectedPath(), duration, dia->clipName(), parentId, properties, std::move(model));
@@ -442,15 +545,15 @@ void ClipCreationDialog::createClipsCommand(KdenliveDoc *doc, const QString &par
     }
 }
 
-void ClipCreationDialog::clipWidget(QDockWidget* m_DockClipWidget)
+void ClipCreationDialog::clipWidget(QDockWidget *m_DockClipWidget)
 {
     QString clipFolder = KRecentDirs::dir(QStringLiteral(":KdenliveClipFolder"));
-    KFileWidget* fileWidget = new KFileWidget(QUrl::fromLocalFile(clipFolder), m_DockClipWidget);
+    KFileWidget *fileWidget = new KFileWidget(QUrl::fromLocalFile(clipFolder), m_DockClipWidget);
     fileWidget->setMode(KFile::Files | KFile::ExistingOnly | KFile::LocalOnly | KFile::Directory);
     QString allExtensions = getExtensions().join(QLatin1Char(' '));
     QString dialogFilter = allExtensions + QLatin1Char('|') + i18n("All Supported Files") + QStringLiteral("\n*|") + i18n("All Files");
 
-    QPushButton* importseq = new QPushButton(i18n("Import image sequence"));
+    QPushButton *importseq = new QPushButton(i18n("Import image sequence"));
     // Make importseq checkable so that we can differentiate between a double click in filewidget and a click on the pushbutton
     importseq->setCheckable(true);
     QCheckBox *b = new QCheckBox(i18n("Ignore subfolder structure"));
@@ -471,14 +574,12 @@ void ClipCreationDialog::clipWidget(QDockWidget* m_DockClipWidget)
             return;
         }
         fileWidget->accept();
-        QList <QUrl> urls = fileWidget->selectedUrls();
+        QList<QUrl> urls = fileWidget->selectedUrls();
         pCore->bin()->droppedUrls(urls);
     });
     fileWidget->setFilter(dialogFilter);
-    QObject::connect(b, &QCheckBox::toggled , [](bool checked) {
-        KdenliveSettings::setIgnoresubdirstructure(checked);
-    });
-    QObject::connect(importseq, &QPushButton::clicked, fileWidget, [=]{
+    QObject::connect(b, &QCheckBox::toggled, [](bool checked) { KdenliveSettings::setIgnoresubdirstructure(checked); });
+    QObject::connect(importseq, &QPushButton::clicked, fileWidget, [=] {
         fileWidget->slotOk();
         emit fileWidget->accepted();
         fileWidget->accept();
@@ -491,7 +592,7 @@ void ClipCreationDialog::clipWidget(QDockWidget* m_DockClipWidget)
         importseq->setChecked(false);
         if (count >= 1) {
             while (fileName.size() > 0 && fileName.at(fileName.size() - 1).isDigit()) {
-                  fileName.chop(1);
+                fileName.chop(1);
             }
             QString parentFolder = "-1";
             KdenliveDoc *doc = pCore->currentDoc();
@@ -506,7 +607,6 @@ void ClipCreationDialog::clipWidget(QDockWidget* m_DockClipWidget)
             int frame_duration = doc->getFramePos(duration) * count;
             ClipCreator::createSlideshowClip(pattern, frame_duration, fileName, parentFolder, properties, pCore->projectItemModel());
             return;
-
         }
     });
     m_DockClipWidget->setWidget(fileWidget);
