@@ -4,8 +4,7 @@
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef KDENLIVESETTINGSDIALOG_H
-#define KDENLIVESETTINGSDIALOG_H
+#pragma once
 
 #include <KConfigDialog>
 #include <KProcess>
@@ -54,6 +53,8 @@ public:
     ~KdenliveSettingsDialog() override;
     void showPage(int page, int option);
     void checkProfile();
+    /** @brief update kdenlive settings for external app path if they were changed outside config dialog */
+    void updateExternalApps();
 
 protected slots:
     void updateSettings() override;
@@ -66,6 +67,7 @@ private slots:
     void slotUpdateShuttleDevice(int ix = 0);
     void slotEditImageApplication();
     void slotEditAudioApplication();
+    void slotEditGlaxnimateApplication();
     void slotReadAudioDevices();
     void slotUpdateGrabRegionStatus();
     void slotCheckAlsaDriver();
@@ -82,15 +84,13 @@ private slots:
     void slotDialogModified();
     void slotEnableCaptureFolder();
     void slotEnableLibraryFolder();
-    void slotEnableVideoFolder();
+    void slotEnableVideoFolder(int ix);
     void slotUpdatev4lDevice();
     void slotUpdatev4lCaptureProfile();
     void slotEditVideo4LinuxProfile();
     void slotReloadBlackMagic();
     void slotReloadShuttleDevices();
     void loadExternalProxyProfiles();
-    void slotUpdateAudioCaptureChannels(int index);
-    void slotUpdateAudioCaptureSampleRate(int index);
     void slotParseVoskDictionaries();
     void getDictionary(const QUrl &sourceUrl = QUrl());
     void removeDictionary();
@@ -179,6 +179,6 @@ signals:
     void updateMonitorBg();
     /** @brief Trigger parsing of the speech models folder */
     void parseDictionaries();
+    /** @brief audio volume or rec channels changed, update audio monitor view */
+    void resetAudioMonitoring();
 };
-
-#endif
