@@ -19,17 +19,17 @@
 #include "utils/timecode.h"
 #include "xml/xml.hpp"
 
-#include "renderpresets/tree/renderpresettreemodel.hpp"
-#include "renderpresets/renderpresetrepository.hpp"
 #include "renderpresets/renderpresetmodel.hpp"
+#include "renderpresets/renderpresetrepository.hpp"
 
-#include "klocalizedstring.h"
 #include <KColorScheme>
 #include <KIO/DesktopExecParser>
+#include <KIO/JobUiDelegate>
 #include <KIO/OpenFileManagerWindowJob>
+#include <KIO/OpenUrlJob>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KNotification>
-#include <KRun>
 #include <kio_version.h>
 #include <knotifications_version.h>
 
@@ -46,12 +46,14 @@
 #include <QMenu>
 #include <QMimeDatabase>
 #include <QProcess>
+#include <QScreen>
+#include <QScrollBar>
 #include <QStandardPaths>
+#include <QString>
 #include <QTemporaryFile>
 #include <QThread>
 #include <QTreeWidgetItem>
-#include <qglobal.h>
-#include <qstring.h>
+#include <QtGlobal>
 
 #ifdef KF5_USE_PURPOSE
 #include <Purpose/AlternativesModel>
@@ -71,7 +73,8 @@ enum {
     ExtraInfoRole = ProgressRole + 2, // vpinon: don't understand why, else spurious message displayed
     LastTimeRole,
     LastFrameRole,
-    OpenBrowserRole
+    OpenBrowserRole,
+    PlayAfterRole
 };
 
 // Running job status
@@ -149,7 +152,7 @@ RenderWidget::RenderWidget(bool enableProxy, QWidget *parent)
     m_view.buttonRender->setEnabled(false);
     m_view.buttonGenerateScript->setEnabled(false);
 
-    connect(m_view.profileTree, &QTreeView::doubleClicked, this, [&](const QModelIndex &index){
+    connect(m_view.profileTree, &QTreeView::doubleClicked, this, [&](const QModelIndex &index) {
         if (m_treeModel->parent(index) == QModelIndex()) {
             // This is a top level item - group - don't edit
             return;
@@ -158,14 +161,14 @@ RenderWidget::RenderWidget(bool enableProxy, QWidget *parent)
     });
     connect(m_view.buttonNew, &QAbstractButton::clicked, this, &RenderWidget::slotNewPreset);
     connect(m_view.buttonEdit, &QAbstractButton::clicked, this, &RenderWidget::slotEditPreset);
-    connect(m_view.buttonDelete, &QAbstractButton::clicked, this, [this](){
+    connect(m_view.buttonDelete, &QAbstractButton::clicked, this, [this]() {
         RenderPresetRepository::get()->deletePreset(m_currentProfile);
         m_currentProfile = QString();
         parseProfiles();
         refreshView();
     });
     connect(m_view.buttonSaveAs, &QAbstractButton::clicked, this, &RenderWidget::slotSavePresetAs);
-    connect(m_view.buttonDownload, &QAbstractButton::clicked, this, [&](){
+    connect(m_view.buttonDownload, &QAbstractButton::clicked, this, [&]() {
         if (pCore->getNewStuff(QStringLiteral(":data/kdenlive_renderprofiles.knsrc")) > 0) {
             parseProfiles();
         }
@@ -185,7 +188,6 @@ RenderWidget::RenderWidget(bool enableProxy, QWidget *parent)
     connect(m_view.guide_end, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &RenderWidget::slotCheckStartGuidePosition);
     connect(m_view.guide_start, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &RenderWidget::slotCheckEndGuidePosition);
 
-
     // === "More Options" widget ===
     setRescaleEnabled(false);
     m_view.guide_zone_box->setVisible(false);
@@ -197,9 +199,8 @@ RenderWidget::RenderWidget(bool enableProxy, QWidget *parent)
     m_view.tc_type->addItem(i18n("Frame Number"), QStringLiteral("#frame#"));
     m_view.checkTwoPass->setEnabled(false);
     m_view.proxy_render->setHidden(!enableProxy);
-    connect(m_view.proxy_render, &QCheckBox::toggled, this, [&](bool enabled){
-        errorMessage(ProxyWarning, enabled ? i18n("Rendering using low quality proxy") : QString());
-    });
+    connect(m_view.proxy_render, &QCheckBox::toggled, this,
+            [&](bool enabled) { errorMessage(ProxyWarning, enabled ? i18n("Rendering using low quality proxy") : QString()); });
 
     connect(m_view.quality, &QAbstractSlider::valueChanged, this, &RenderWidget::refreshParams);
     connect(m_view.qualityGroup, &QGroupBox::toggled, this, &RenderWidget::refreshParams);
@@ -218,20 +219,25 @@ RenderWidget::RenderWidget(bool enableProxy, QWidget *parent)
     connect(m_view.rescale_width, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &RenderWidget::slotUpdateRescaleWidth);
     connect(m_view.rescale_height, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &RenderWidget::slotUpdateRescaleHeight);
     connect(m_view.rescale_keep, &QAbstractButton::clicked, this, &RenderWidget::slotSwitchAspectRatio);
-    m_view.parallel_process->setChecked(KdenliveSettings::parallelrender());
-    connect(m_view.parallel_process, &QCheckBox::stateChanged, [&](int state) {
+    m_view.processing_threads->setMaximum(QThread::idealThreadCount() - 1);
+    m_view.processing_threads->setValue(KdenliveSettings::processingthreads());
+    connect(m_view.processing_threads, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KdenliveSettings::setProcessingthreads);
+    connect(m_view.processing_threads, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &RenderWidget::refreshParams);
+    m_view.processing_box->setChecked(KdenliveSettings::parallelrender());
+    connect(m_view.processing_box, &QGroupBox::toggled, [&](int state) {
         KdenliveSettings::setParallelrender(state == Qt::Checked);
         refreshParams();
     });
     if (KdenliveSettings::gpu_accel()) {
         // Disable parallel rendering for movit
-        m_view.parallel_process->setEnabled(false);
+        m_view.processing_box->setChecked(false);
+        m_view.processing_box->setEnabled(false);
     }
     connect(m_view.export_meta, &QCheckBox::stateChanged, this, &RenderWidget::refreshParams);
     connect(m_view.checkTwoPass, &QCheckBox::stateChanged, this, &RenderWidget::refreshParams);
 
-    connect(m_view.buttonRender, &QAbstractButton::clicked, this, [&](){ slotPrepareExport(); });
-    connect(m_view.buttonGenerateScript, &QAbstractButton::clicked, this, [&](){ slotPrepareExport(true); });
+    connect(m_view.buttonRender, &QAbstractButton::clicked, this, [&]() { slotPrepareExport(); });
+    connect(m_view.buttonGenerateScript, &QAbstractButton::clicked, this, [&]() { slotPrepareExport(true); });
 
     m_view.infoMessage->hide();
     m_view.jobInfo->hide();
@@ -275,7 +281,7 @@ RenderWidget::RenderWidget(bool enableProxy, QWidget *parent)
     header->setSectionResizeMode(0, QHeaderView::Fixed);
     header->resizeSection(0, size + 4);
 
-// Find path for Kdenlive renderer
+    // Find path for Kdenlive renderer
 #ifdef Q_OS_WIN
     m_renderer = QCoreApplication::applicationDirPath() + QStringLiteral("/kdenlive_render.exe");
 #else
@@ -284,7 +290,8 @@ RenderWidget::RenderWidget(bool enableProxy, QWidget *parent)
     if (!QFile::exists(m_renderer)) {
         m_renderer = QStandardPaths::findExecutable(QStringLiteral("kdenlive_render"));
         if (m_renderer.isEmpty()) {
-            KMessageBox::sorry(this, i18n("Could not find the kdenlive_render application, something is wrong with your installation. Rendering will not work"));
+            KMessageBox::sorry(this,
+                               i18n("Could not find the kdenlive_render application, something is wrong with your installation. Rendering will not work"));
         }
     }
 
@@ -307,6 +314,7 @@ RenderWidget::RenderWidget(bool enableProxy, QWidget *parent)
     refreshView();
     focusItem();
     adjustSize();
+    m_view.embed_subtitles->setToolTip(i18n("Only works for the matroska (mkv) format"));
 }
 
 void RenderWidget::slotShareActionFinished(const QJsonObject &output, int error, const QString &message)
@@ -336,11 +344,7 @@ void RenderWidget::slotShareActionFinished(const QJsonObject &output, int error,
 QSize RenderWidget::sizeHint() const
 {
     // Make sure the widget has minimum size on opening
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    return {200, 200};
-#else
     return {200, qMax(200, screen()->availableGeometry().height())};
-#endif
 }
 
 RenderWidget::~RenderWidget()
@@ -481,7 +485,7 @@ void RenderWidget::reloadGuides()
 
             // Set up guide categories
             static std::array<QColor, 9> markerTypes = ptr->markerTypes;
-            QPixmap pixmap(32,32);
+            QPixmap pixmap(32, 32);
             m_view.guideCategoryCombo->addItem(i18n("All Categories"), -1);
             for (uint i = 0; i < markerTypes.size(); ++i) {
                 if (!ptr->getAllMarkers(i).isEmpty()) {
@@ -532,7 +536,6 @@ void RenderWidget::slotUpdateButtons(const QUrl &url)
     }
 }
 
-
 void RenderWidget::slotUpdateButtons()
 {
     slotUpdateButtons(QUrl());
@@ -574,7 +577,7 @@ void RenderWidget::slotEditPreset()
     }
 
     QPointer<RenderPresetDialog> dialog = new RenderPresetDialog(this, profile.get(), RenderPresetDialog::Edit);
-    if (dialog->exec() == QDialog::Accepted) {      
+    if (dialog->exec() == QDialog::Accepted) {
         parseProfiles(dialog->saveName());
     }
     delete dialog;
@@ -635,21 +638,12 @@ void RenderWidget::prepareRendering(bool delayedRendering)
 
     KdenliveDoc *project = pCore->currentDoc();
     QString overlayData = m_view.tc_type->currentData().toString();
-    QString playlistContent = pCore->projectManager()->projectSceneList(project->url().adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toLocalFile(), overlayData);
+    QString playlistContent =
+        pCore->projectManager()->projectSceneList(project->url().adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toLocalFile(), overlayData);
 
     // Set playlist audio volume to 100%
     QDomDocument doc;
     doc.setContent(playlistContent);
-    QDomElement tractor = doc.documentElement().firstChildElement(QStringLiteral("tractor"));
-    if (!tractor.isNull()) {
-        QDomNodeList props = tractor.elementsByTagName(QStringLiteral("property"));
-        for (int i = 0; i < props.count(); ++i) {
-            if (props.at(i).toElement().attribute(QStringLiteral("name")) == QLatin1String("meta.volume")) {
-                props.at(i).firstChild().setNodeValue(QStringLiteral("1"));
-                break;
-            }
-        }
-    }
 
     // Add autoclose to playlists.
     QDomNodeList playlists = doc.elementsByTagName(QStringLiteral("playlist"));
@@ -669,17 +663,41 @@ void RenderWidget::prepareRendering(bool delayedRendering)
     int out = pCore->projectDuration() - 2;
     Monitor *pMon = pCore->getMonitor(Kdenlive::ProjectMonitor);
     double fps = pCore->getCurrentProfile()->fps();
+    QString subtitleFile;
+    if (m_view.embed_subtitles->isEnabled() && m_view.embed_subtitles->isChecked() && project->hasSubtitles()) {
+        QTemporaryFile src(QDir::temp().absoluteFilePath(QString("XXXXXX.srt")));
+        if (!src.open()) {
+            // Something went wrong
+            KMessageBox::sorry(this, i18n("Could not create temporary subtitle file"));
+            return;
+        }
+        subtitleFile = src.fileName();
+        src.setAutoRemove(false);
+        // disable subtitle filter(s) as they will be embeded in a second step of rendering
+        QDomNodeList filters = doc.elementsByTagName(QStringLiteral("filter"));
+        for (int i = 0; i < filters.length(); ++i) {
+            if (Xml::getXmlProperty(filters.item(i).toElement(), QStringLiteral("mlt_service")) == QLatin1String("avfilter.subtitles")) {
+                Xml::setXmlProperty(filters.item(i).toElement(), QStringLiteral("disable"), QStringLiteral("1"));
+            }
+        }
+    }
     if (m_view.render_zone->isChecked()) {
         in = pMon->getZoneStart();
         out = pMon->getZoneEnd() - 1;
-        generateRenderFiles(doc, in, out, outputFile, delayedRendering);
+        if (!subtitleFile.isEmpty()) {
+            project->generateRenderSubtitleFile(in, out, subtitleFile);
+        }
+        generateRenderFiles(doc, in, out, outputFile, delayedRendering, subtitleFile);
     } else if (m_view.render_guide->isChecked()) {
         double guideStart = m_view.guide_start->itemData(m_view.guide_start->currentIndex()).toDouble();
         double guideEnd = m_view.guide_end->itemData(m_view.guide_end->currentIndex()).toDouble();
         in = int(GenTime(guideStart).frames(fps));
         // End rendering at frame before last guide
         out = int(GenTime(guideEnd).frames(fps)) - 1;
-        generateRenderFiles(doc, in, out, outputFile, delayedRendering);
+        if (!subtitleFile.isEmpty()) {
+            project->generateRenderSubtitleFile(in, out, subtitleFile);
+        }
+        generateRenderFiles(doc, in, out, outputFile, delayedRendering, subtitleFile);
     } else if (m_view.render_multi->isChecked()) {
         if (auto ptr = m_guidesModel.lock()) {
             int category = m_view.guideCategoryCombo->currentData().toInt();
@@ -711,18 +729,35 @@ void RenderWidget::prepareRendering(bool delayedRendering)
                     names.append(newName);
                     name = newName;
                     if (in < absoluteOut) {
-                        if (i+1 < markers.count()) {
-                            out = qMin(markers.at(i+1).time().frames(fps) - 1, absoluteOut);
+                        if (i + 1 < markers.count()) {
+                            out = qMin(markers.at(i + 1).time().frames(fps) - 1, absoluteOut);
                         }
-                        QString filename = outputFile.section(QLatin1Char('.'), 0, -2) + QStringLiteral("-%1.").arg(name) + outputFile.section(QLatin1Char('.'), -1);
+                        QString filename =
+                            outputFile.section(QLatin1Char('.'), 0, -2) + QStringLiteral("-%1.").arg(name) + outputFile.section(QLatin1Char('.'), -1);
                         QDomDocument docCopy = doc.cloneNode(true).toDocument();
-                        generateRenderFiles(docCopy, in, out, filename, false);
+                        if (!subtitleFile.isEmpty()) {
+                            project->generateRenderSubtitleFile(in, out, subtitleFile);
+                        }
+                        generateRenderFiles(docCopy, in, out, filename, false, subtitleFile);
+                        if (!subtitleFile.isEmpty() && i < markers.count() - 1) {
+                            QTemporaryFile src(QDir::temp().absoluteFilePath(QString("XXXXXX.srt")));
+                            if (!src.open()) {
+                                // Something went wrong
+                                KMessageBox::sorry(this, i18n("Could not create temporary subtitle file"));
+                                return;
+                            }
+                            subtitleFile = src.fileName();
+                            src.setAutoRemove(false);
+                        }
                     }
                 }
             }
         }
     } else {
-        generateRenderFiles(doc, in, out, outputFile, delayedRendering);
+        if (!subtitleFile.isEmpty()) {
+            project->generateRenderSubtitleFile(in, out, subtitleFile);
+        }
+        generateRenderFiles(doc, in, out, outputFile, delayedRendering, subtitleFile);
     }
 }
 
@@ -748,7 +783,8 @@ QString RenderWidget::generatePlaylistFile(bool delayedRendering)
             newFilename = QStringLiteral("%1-%2").arg(filename).arg(ix);
             ix++;
         }
-        filename = QInputDialog::getText(this, i18nc("@title:window", "Delayed Rendering"), i18n("Select a name for this rendering."), QLineEdit::Normal, newFilename, &ok);
+        filename = QInputDialog::getText(this, i18nc("@title:window", "Delayed Rendering"), i18n("Select a name for this rendering."), QLineEdit::Normal,
+                                         newFilename, &ok);
         if (!ok) {
             return {};
         }
@@ -772,7 +808,7 @@ QString RenderWidget::generatePlaylistFile(bool delayedRendering)
     return tmp.fileName();
 }
 
-void RenderWidget::generateRenderFiles(QDomDocument doc, int in, int out, QString outputFile, bool delayedRendering)
+void RenderWidget::generateRenderFiles(QDomDocument doc, int in, int out, QString outputFile, bool delayedRendering, const QString &subtitleFile)
 {
     QString playlistPath = generatePlaylistFile(delayedRendering);
     QString extension = outputFile.section(QLatin1Char('.'), -1);
@@ -780,7 +816,6 @@ void RenderWidget::generateRenderFiles(QDomDocument doc, int in, int out, QStrin
     if (playlistPath.isEmpty()) {
         return;
     }
-
     QString renderArgs = m_view.advanced_params->toPlainText().simplified();
     QDomElement consumer = doc.createElement(QStringLiteral("consumer"));
     consumer.setAttribute(QStringLiteral("in"), in);
@@ -806,14 +841,10 @@ void RenderWidget::generateRenderFiles(QDomDocument doc, int in, int out, QStrin
 
     // If we use a pix_fmt with alpha channel (ie. transparent),
     // we need to remove the black background track
-    if (renderArgs.contains(QLatin1String("pix_fmt=argb"))
-     || renderArgs.contains(QLatin1String("pix_fmt=abgr"))
-     || renderArgs.contains(QLatin1String("pix_fmt=bgra"))
-     || renderArgs.contains(QLatin1String("pix_fmt=gbra"))
-     || renderArgs.contains(QLatin1String("pix_fmt=rgba"))
-     || renderArgs.contains(QLatin1String("pix_fmt=yuva"))
-     || renderArgs.contains(QLatin1String("pix_fmt=ya"  ))
-     || renderArgs.contains(QLatin1String("pix_fmt=ayuv"))) {
+    if (renderArgs.contains(QLatin1String("pix_fmt=argb")) || renderArgs.contains(QLatin1String("pix_fmt=abgr")) ||
+        renderArgs.contains(QLatin1String("pix_fmt=bgra")) || renderArgs.contains(QLatin1String("pix_fmt=gbra")) ||
+        renderArgs.contains(QLatin1String("pix_fmt=rgba")) || renderArgs.contains(QLatin1String("pix_fmt=yuva")) ||
+        renderArgs.contains(QLatin1String("pix_fmt=ya")) || renderArgs.contains(QLatin1String("pix_fmt=ayuv"))) {
         auto prods = doc.elementsByTagName(QStringLiteral("producer"));
         for (int i = 0; i < prods.count(); ++i) {
             auto prod = prods.at(i).toElement();
@@ -825,8 +856,7 @@ void RenderWidget::generateRenderFiles(QDomDocument doc, int in, int out, QStrin
     }
 
     QMap<QString, QString> renderFiles;
-    if (renderArgs.contains("=stills/"))
-    {
+    if (renderArgs.contains("=stills/")) {
         // Image sequence, ensure we have a %0xd at file end.
         // Format string for counter
         QRegularExpression rx(QRegularExpression::anchoredPattern(QStringLiteral(".*%[0-9]*d.*")));
@@ -838,8 +868,9 @@ void RenderWidget::generateRenderFiles(QDomDocument doc, int in, int out, QStrin
     if (m_view.stemAudioExport->isChecked() && m_view.stemAudioExport->isEnabled()) {
         if (delayedRendering) {
             if (KMessageBox::warningContinueCancel(this, i18n("Script rendering and multi track audio export can not be used together.\n"
-                                                        "Script will be saved without multi track export."))
-                                                   == KMessageBox::Cancel) { return; };
+                                                              "Script will be saved without multi track export.")) == KMessageBox::Cancel) {
+                return;
+            };
         }
         int audioCount = 0;
         QDomNodeList orginalTractors = doc.elementsByTagName(QStringLiteral("tractor"));
@@ -849,7 +880,10 @@ void RenderWidget::generateRenderFiles(QDomDocument doc, int in, int out, QStrin
             QString trackName = Xml::getXmlProperty(orginalTractors.at(i).toElement(), QStringLiteral("kdenlive:track_name"));
             if (isAudio) {
                 // setup filenames
-                QString appendix = QString("_Audio_%1%2%3.").arg(audioCount + 1).arg(trackName.isEmpty() ? QString() : QStringLiteral("-")).arg(trackName.replace(QStringLiteral(" "), QStringLiteral("_")));
+                QString appendix = QString("_Audio_%1%2%3.")
+                                       .arg(audioCount + 1)
+                                       .arg(trackName.isEmpty() ? QString() : QStringLiteral("-"))
+                                       .arg(trackName.replace(QStringLiteral(" "), QStringLiteral("_")));
                 QString playlistFile = playlistPath.section(QLatin1Char('.'), 0, -2) + appendix + playlistPath.section(QLatin1Char('.'), -1);
                 QString targetFile = outputFile.section(QLatin1Char('.'), 0, -2) + appendix + extension;
                 renderFiles.insert(playlistFile, targetFile);
@@ -884,7 +918,6 @@ void RenderWidget::generateRenderFiles(QDomDocument doc, int in, int out, QStrin
                 file.close();
                 audioCount++;
             }
-
         }
     }
 
@@ -951,7 +984,7 @@ void RenderWidget::generateRenderFiles(QDomDocument doc, int in, int out, QStrin
     QList<RenderJobItem *> jobList;
     QMap<QString, QString>::const_iterator i = renderFiles.constBegin();
     while (i != renderFiles.constEnd()) {
-        RenderJobItem *renderItem = createRenderJob(i.key(), i.value(), in, out);
+        RenderJobItem *renderItem = createRenderJob(i.key(), i.value(), in, out, subtitleFile);
         if (renderItem != nullptr) {
             jobList << renderItem;
         }
@@ -965,7 +998,7 @@ void RenderWidget::generateRenderFiles(QDomDocument doc, int in, int out, QStrin
     checkRenderStatus();
 }
 
-RenderJobItem *RenderWidget::createRenderJob(const QString &playlist, const QString &outputFile, int in, int out)
+RenderJobItem *RenderWidget::createRenderJob(const QString &playlist, const QString &outputFile, int in, int out, const QString &subtitleFile)
 {
     QList<QTreeWidgetItem *> existing = m_view.running_jobs->findItems(outputFile, Qt::MatchExactly, 1);
     RenderJobItem *renderItem = nullptr;
@@ -974,8 +1007,8 @@ RenderJobItem *RenderWidget::createRenderJob(const QString &playlist, const QStr
         if (renderItem->status() == RUNNINGJOB || renderItem->status() == WAITINGJOB || renderItem->status() == STARTINGJOB) {
             // There is an existing job that is still pending
             KMessageBox::information(this,
-                i18n("There is already a job writing file:<br /><b>%1</b><br />Abort the job if you want to overwrite it…", outputFile),
-                i18n("Already running"));
+                                     i18n("There is already a job writing file:<br /><b>%1</b><br />Abort the job if you want to overwrite it…", outputFile),
+                                     i18n("Already running"));
             // focus the running job
             m_view.running_jobs->setCurrentItem(renderItem);
             return nullptr;
@@ -990,11 +1023,19 @@ RenderJobItem *RenderWidget::createRenderJob(const QString &playlist, const QStr
     renderItem->setData(1, StartTimeRole, t);
     renderItem->setData(1, LastTimeRole, t);
     renderItem->setData(1, LastFrameRole, in);
-    QStringList argsJob = {KdenliveSettings::rendererpath(), playlist, outputFile,
-                           QStringLiteral("-pid:%1").arg(QCoreApplication::applicationPid()), QStringLiteral("-out"), QString::number(out)};
+    QStringList argsJob = {KdenliveSettings::rendererpath(),
+                           playlist,
+                           outputFile,
+                           QStringLiteral("-pid:%1").arg(QCoreApplication::applicationPid()),
+                           QStringLiteral("-out"),
+                           QString::number(out)};
+    if (!subtitleFile.isEmpty()) {
+        argsJob << QStringLiteral("-subtitle") << subtitleFile;
+    }
     renderItem->setData(1, ParametersRole, argsJob);
     qDebug() << "* CREATED JOB WITH ARGS: " << argsJob;
     renderItem->setData(1, OpenBrowserRole, m_view.open_browser->isChecked());
+    renderItem->setData(1, PlayAfterRole, m_view.play_after->isChecked());
     if (!m_view.audio_box->isChecked()) {
         renderItem->setData(1, ExtraInfoRole, i18n("Video without audio track"));
     } else if (!m_view.video_box->isChecked()) {
@@ -1208,6 +1249,7 @@ void RenderWidget::loadProfile()
     m_view.checkTwoPass->setChecked(passes && params.contains(QStringLiteral("passes=2")));
 
     m_view.encoder_threads->setEnabled(!profile->hasParam(QStringLiteral("threads")));
+    m_view.embed_subtitles->setEnabled(profile->extension() == QLatin1String("mkv") || profile->extension() == QLatin1String("matroska"));
 
     m_view.video_box->setChecked(profile->getParam(QStringLiteral("vn")) != QStringLiteral("1"));
     m_view.audio_box->setChecked(profile->getParam(QStringLiteral("an")) != QStringLiteral("1"));
@@ -1234,13 +1276,8 @@ void RenderWidget::refreshParams()
         setRescaleEnabled(m_view.video_box->isChecked() && m_view.rescale->isChecked());
     }
 
-    QStringList removeParams = {
-        QStringLiteral("an"),
-        QStringLiteral("audio_off"),
-        QStringLiteral("vn"),
-        QStringLiteral("video_off"),
-        QStringLiteral("real_time")
-    };
+    QStringList removeParams = {QStringLiteral("an"), QStringLiteral("audio_off"), QStringLiteral("vn"), QStringLiteral("video_off"),
+                                QStringLiteral("real_time")};
 
     QStringList newParams;
 
@@ -1262,10 +1299,11 @@ void RenderWidget::refreshParams()
     // Rescale
     bool rescale = m_view.rescale->isEnabled() && m_view.rescale->isChecked();
     if (rescale) {
-        removeParams.append({QStringLiteral("s"), QStringLiteral("width"), QStringLiteral("height"), QStringLiteral("sample_aspect_num"), QStringLiteral("sample_aspect_den")});
+        removeParams.append(
+            {QStringLiteral("s"), QStringLiteral("width"), QStringLiteral("height"), QStringLiteral("sample_aspect_num"), QStringLiteral("sample_aspect_den")});
         newParams.append(QStringLiteral("s=%1x%2").arg(m_view.rescale_width->value()).arg(m_view.rescale_height->value()));
         if (preset->hasParam(QStringLiteral("sample_aspect_num")) || preset->hasParam(QStringLiteral("sample_aspect_den"))) {
-            //reset display aspect ratio to 1:1 if we override the resolution to avoid errors
+            // reset display aspect ratio to 1:1 if we override the resolution to avoid errors
             newParams.append(QStringLiteral("sample_aspect_num=1 sample_aspect_den=1"));
         }
     }
@@ -1295,11 +1333,9 @@ void RenderWidget::refreshParams()
     }
 
     // Parallel Processing
-    int threadCount = QThread::idealThreadCount();
-    if (threadCount < 2 || !m_view.parallel_process->isChecked() || !m_view.parallel_process->isEnabled()) {
+    int threadCount = KdenliveSettings::processingthreads();
+    if (!m_view.processing_box->isChecked() || !m_view.processing_box->isEnabled()) {
         threadCount = 1;
-    } else {
-        threadCount = qMin(4, threadCount - 1);
     }
     newParams.append(QStringLiteral("real_time=%1").arg(-threadCount));
 
@@ -1399,7 +1435,9 @@ void RenderWidget::refreshParams()
         params.replace(QLatin1String("%dv_standard"), dvstd);
     }
 
-    params.replace(QLatin1String("%dar"), QStringLiteral("@%1/%2").arg(QString::number(projectProfile->display_aspect_num())).arg(QString::number(projectProfile->display_aspect_den())));
+    params.replace(
+        QLatin1String("%dar"),
+        QStringLiteral("@%1/%2").arg(QString::number(projectProfile->display_aspect_num())).arg(QString::number(projectProfile->display_aspect_den())));
     params.replace(QLatin1String("%passes"), QString::number(static_cast<int>(m_view.checkTwoPass->isChecked()) + 1));
 
     newParams.prepend(params);
@@ -1506,10 +1544,17 @@ void RenderWidget::setRenderStatus(const QString &dest, int status, const QStrin
         notify->setText(notif);
         notify->setUrls({QUrl::fromLocalFile(dest)});
         notify->sendEvent();
-        QUrl url = QUrl::fromLocalFile(item->text(1));
+        const QUrl url = QUrl::fromLocalFile(item->text(1));
         bool exists = QFile(url.toLocalFile()).exists();
-        if (exists && item->data(1, OpenBrowserRole).toBool()) {
-            KIO::highlightInFileManager({url});
+        if (exists) {
+            if (item->data(1, OpenBrowserRole).toBool()) {
+                KIO::highlightInFileManager({url});
+            }
+            if (item->data(1, PlayAfterRole).toBool()) {
+                auto *job = new KIO::OpenUrlJob(url);
+                job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+                job->start();
+            }
         }
     } else if (status == -2) {
         // Rendering crashed
@@ -1609,7 +1654,8 @@ void RenderWidget::parseScriptFiles()
     QStringList scriptFiles = projectFolder.entryList(scriptsFilter, QDir::Files);
     if (scriptFiles.isEmpty()) {
         // No scripts, delete directory
-        if (projectFolder.dirName() == QStringLiteral("kdenlive-renderqueue") && projectFolder.entryList(scriptsFilter, QDir::AllEntries | QDir::NoDotAndDotDot).isEmpty()) {
+        if (projectFolder.dirName() == QStringLiteral("kdenlive-renderqueue") &&
+            projectFolder.entryList(scriptsFilter, QDir::AllEntries | QDir::NoDotAndDotDot).isEmpty()) {
             projectFolder.removeRecursively();
             return;
         }
@@ -1698,7 +1744,12 @@ void RenderWidget::slotStartScript()
         QDateTime t = QDateTime::currentDateTime();
         renderItem->setData(1, StartTimeRole, t);
         renderItem->setData(1, LastTimeRole, t);
-        QStringList argsJob = {KdenliveSettings::rendererpath(), path, destination, QStringLiteral("-pid:%1").arg(QCoreApplication::applicationPid()),QStringLiteral("-out"),QString::number(out)};
+        QStringList argsJob = {KdenliveSettings::rendererpath(),
+                               path,
+                               destination,
+                               QStringLiteral("-pid:%1").arg(QCoreApplication::applicationPid()),
+                               QStringLiteral("-out"),
+                               QString::number(out)};
         renderItem->setData(1, ParametersRole, argsJob);
         checkRenderStatus();
         m_view.tabWidget->setCurrentIndex(Tabs::JobsTab);
@@ -1869,7 +1920,9 @@ bool RenderWidget::startWaitingRenderJobs()
     }
 
     QTextStream outStream(&file);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     outStream.setCodec("UTF-8");
+#endif
 #ifndef Q_OS_WIN
     outStream << "#!/bin/sh\n\n";
 #endif
@@ -1906,7 +1959,9 @@ void RenderWidget::slotPlayRendering(QTreeWidgetItem *item, int)
     if (renderItem->status() != FINISHEDJOB) {
         return;
     }
-    new KRun(QUrl::fromLocalFile(item->text(1)), this);
+    auto *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(item->text(1)));
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->start();
 }
 
 void RenderWidget::errorMessage(RenderError type, const QString &message)
@@ -2007,11 +2062,9 @@ void RenderWidget::prepareJobContextMenu(const QPoint &pos)
     }
     QMenu menu(this);
     QAction *newAct = new QAction(i18n("Add to current project"), this);
-    connect(newAct, &QAction::triggered, [&, renderItem]() {
-        pCore->bin()->slotAddClipToProject(QUrl::fromLocalFile(renderItem->text(1)));
-    });
+    connect(newAct, &QAction::triggered, [&, renderItem]() { pCore->bin()->slotAddClipToProject(QUrl::fromLocalFile(renderItem->text(1))); });
     menu.addAction(newAct);
-    
+
     menu.exec(m_view.running_jobs->mapToGlobal(pos));
 }
 
@@ -2024,7 +2077,8 @@ void RenderWidget::resetRenderPath(const QString &path)
     } else {
         extension = m_view.out_file->url().toLocalFile().section(QLatin1Char('.'), -1);
     }
-    QString fileName = QDir(pCore->currentDoc()->projectDataFolder()).absoluteFilePath(path + extension);
+    QFileInfo updatedPath(path);
+    QString fileName = QDir(pCore->currentDoc()->projectDataFolder(updatedPath.absolutePath())).absoluteFilePath(updatedPath.fileName());
     QString url = filenameWithExtension(QUrl::fromLocalFile(fileName), extension).toLocalFile();
     if (QFileInfo(url).isRelative()) {
         url.prepend(pCore->currentDoc()->documentRoot());
