@@ -3,8 +3,7 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef EFFECTITEMMODEL_H
-#define EFFECTITEMMODEL_H
+#pragma once
 
 #include "abstracteffectitem.hpp"
 #include "abstractmodel/treeitem.hpp"
@@ -25,7 +24,8 @@ public:
     /** @brief This construct an effect with an already existing filter
        Only used when loading an existing clip
      */
-    static std::shared_ptr<EffectItemModel> construct(std::unique_ptr<Mlt::Properties> effect, std::shared_ptr<AbstractTreeModel> stack, const QString &originalDecimalPoint);
+    static std::shared_ptr<EffectItemModel> construct(std::unique_ptr<Mlt::Properties> effect, std::shared_ptr<AbstractTreeModel> stack,
+                                                      const QString &originalDecimalPoint);
 
     /** @brief This function plants the effect into the given service in last position
      */
@@ -47,8 +47,8 @@ public:
     bool isCollapsed() const;
     bool hasForcedInOut() const;
     bool isValid() const;
-    QPair <int, int> getInOut() const;
-    void setInOut(const QString &effectName, QPair<int, int>bounds, bool enabled, bool withUndo);
+    QPair<int, int> getInOut() const;
+    void setInOut(const QString &effectName, QPair<int, int> bounds, bool enabled, bool withUndo);
 
 protected:
     EffectItemModel(const QList<QVariant> &effectData, std::unique_ptr<Mlt::Properties> effect, const QDomElement &xml, const QString &effectId,
@@ -57,5 +57,3 @@ protected:
     void updateEnable(bool updateTimeline = true) override;
     int m_childId;
 };
-
-#endif
