@@ -17,24 +17,24 @@
 #include <QDialog>
 #include <QFileDialog>
 #include <QFontDatabase>
+#include <QFormLayout>
 #include <QInputDialog>
 #include <QLabel>
 #include <QMenu>
 #include <QMimeData>
+#include <QPointer>
 #include <QProgressBar>
 #include <QSpinBox>
 #include <QStandardPaths>
+#include <QTextEdit>
 #include <QVBoxLayout>
 #include <QWheelEvent>
-#include <QPointer>
-#include <QFormLayout>
-#include <QTextEdit>
 
-#include <QComboBox>
 #include <KDualAction>
 #include <KMessageBox>
 #include <KRecentDirs>
 #include <KSqueezedTextLabel>
+#include <QComboBox>
 #include <klocalizedstring.h>
 
 CollapsibleEffectView::CollapsibleEffectView(const std::shared_ptr<EffectItemModel> &effectModel, QSize frameSize, const QImage &icon, QWidget *parent)
@@ -95,7 +95,7 @@ CollapsibleEffectView::CollapsibleEffectView(const std::shared_ptr<EffectItemMod
     m_enabledButton->setInactiveIcon(QIcon::fromTheme(QStringLiteral("visibility")));
     enabledButton->setDefaultAction(m_enabledButton);
     connect(m_model.get(), &AssetParameterModel::enabledChange, this, &CollapsibleEffectView::enableView);
-    connect(m_model.get(), &AssetParameterModel::showEffectZone, this, [=] (ObjectId id, QPair <int, int>inOut, bool checked) {
+    connect(m_model.get(), &AssetParameterModel::showEffectZone, this, [=](ObjectId id, QPair<int, int> inOut, bool checked) {
         m_inOutButton->setChecked(checked);
         zoneFrame->setFixedHeight(checked ? frame->height() : 0);
         slotSwitch(m_collapse->isActive());
@@ -109,7 +109,7 @@ CollapsibleEffectView::CollapsibleEffectView(const std::shared_ptr<EffectItemMod
     });
     m_groupAction = new QAction(QIcon::fromTheme(QStringLiteral("folder-new")), i18n("Create Group"), this);
     connect(m_groupAction, &QAction::triggered, this, &CollapsibleEffectView::slotCreateGroup);
-    
+
     // In /out effect button
     auto *layZone = new QHBoxLayout(zoneFrame);
     layZone->setContentsMargins(0, 0, 0, 0);
@@ -135,7 +135,7 @@ CollapsibleEffectView::CollapsibleEffectView(const std::shared_ptr<EffectItemMod
     layZone->addWidget(setOut);
     m_outPos = new TimecodeDisplay(pCore->timecode(), this);
     layZone->addWidget(m_outPos);
-    
+
     connect(setIn, &QToolButton::clicked, this, [=]() {
         if (m_model->getOwnerId().first == ObjectType::BinClip) {
             m_outPos->setValue(pCore->getMonitor(Kdenlive::ClipMonitor)->position());
@@ -152,7 +152,7 @@ CollapsibleEffectView::CollapsibleEffectView(const std::shared_ptr<EffectItemMod
         }
         updateEffectZone();
     });
-    
+
     m_inOutButton = new QAction(QIcon::fromTheme(QStringLiteral("zoom-fit-width")), i18n("Use effect zone"), this);
     m_inOutButton->setCheckable(true);
     inOutButton->setDefaultAction(m_inOutButton);
@@ -199,7 +199,7 @@ CollapsibleEffectView::CollapsibleEffectView(const std::shared_ptr<EffectItemMod
     lay->setSpacing(0);
     lay->addWidget(m_view);
     connect(keyframesButton, &QToolButton::toggled, this, [this](bool toggle) {
-        if(toggle) {
+        if (toggle) {
             keyframesButton->setIcon(QIcon::fromTheme(QStringLiteral("keyframe")));
         } else {
             keyframesButton->setIcon(QIcon::fromTheme(QStringLiteral("keyframe-disable")));
@@ -225,7 +225,7 @@ CollapsibleEffectView::CollapsibleEffectView(const std::shared_ptr<EffectItemMod
 
     connect(saveEffectButton, &QAbstractButton::clicked, this, &CollapsibleEffectView::slotSaveEffect);
     saveEffectButton->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
-    saveEffectButton->setToolTip(i18n("Save Effect"));
+    saveEffectButton->setToolTip(i18n("Save effect"));
 
     if (!effectModel->isEnabled()) {
         title->setEnabled(false);
@@ -312,39 +312,30 @@ bool CollapsibleEffectView::eventFilter(QObject *o, QEvent *e)
     if (e->type() == QEvent::Wheel) {
         auto *we = static_cast<QWheelEvent *>(e);
         if (!m_blockWheel || we->modifiers() != Qt::NoModifier) {
-            e->accept();
             return false;
         }
         if (qobject_cast<QAbstractSpinBox *>(o)) {
-            if (!qobject_cast<QAbstractSpinBox *>(o)->hasFocus()) {
-                e->ignore();
+            if (m_blockWheel && !qobject_cast<QAbstractSpinBox *>(o)->hasFocus()) {
                 return true;
             }
-            e->accept();
             return false;
         }
         if (qobject_cast<QComboBox *>(o)) {
             if (qobject_cast<QComboBox *>(o)->focusPolicy() == Qt::WheelFocus) {
-                e->accept();
                 return false;
             }
-            e->ignore();
             return true;
         }
         if (qobject_cast<QProgressBar *>(o)) {
             if (!qobject_cast<QProgressBar *>(o)->hasFocus()) {
-                e->ignore();
                 return true;
             }
-            e->accept();
             return false;
         }
         if (qobject_cast<WheelContainer *>(o)) {
             if (!qobject_cast<WheelContainer *>(o)->hasFocus()) {
-                e->ignore();
                 return true;
             }
-            e->accept();
             return false;
         }
     }
@@ -392,7 +383,7 @@ void CollapsibleEffectView::slotActivateEffect(bool active)
     if (m_inOutButton->isChecked()) {
         emit showEffectZone(m_model->getOwnerId(), m_model->getInOut(), true);
     } else {
-        emit showEffectZone(m_model->getOwnerId(), {0,0}, false);
+        emit showEffectZone(m_model->getOwnerId(), {0, 0}, false);
     }
 }
 
@@ -470,7 +461,7 @@ void CollapsibleEffectView::slotSaveEffect()
     QDialog dialog(this);
     QFormLayout form(&dialog);
 
-    dialog.setWindowTitle(i18n("Save Effect"));
+    dialog.setWindowTitle(i18nc("@title:window", "Save Effect"));
 
     auto *effectName = new QLineEdit(&dialog);
     auto *descriptionBox = new QTextEdit(&dialog);
@@ -482,11 +473,10 @@ void CollapsibleEffectView::slotSaveEffect()
     QDialogButtonBox buttonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, Qt::Horizontal, &dialog);
     form.addRow(&buttonBox);
 
-    QObject::connect(&buttonBox, SIGNAL(accepted()), &dialog, SLOT(accept()));
-    QObject::connect(&buttonBox, SIGNAL(rejected()), &dialog, SLOT(reject()));
+    QObject::connect(&buttonBox, &QDialogButtonBox::accepted, &dialog, &QDialog::accept);
+    QObject::connect(&buttonBox, &QDialogButtonBox::rejected, &dialog, &QDialog::reject);
 
-    if (dialog.exec() == QDialog::Accepted)
-    {
+    if (dialog.exec() == QDialog::Accepted) {
         QString name = effectName->text();
         QString enteredDescription = descriptionBox->toPlainText();
         if (name.trimmed().isEmpty()) {
@@ -499,7 +489,8 @@ void CollapsibleEffectView::slotSaveEffect()
         }
 
         if (dir.exists(name + QStringLiteral(".xml")))
-            if (KMessageBox::questionYesNo(this, i18n("File %1 already exists.\nDo you want to overwrite it?", name + QStringLiteral(".xml"))) == KMessageBox::No) {
+            if (KMessageBox::questionYesNo(this, i18n("File %1 already exists.\nDo you want to overwrite it?", name + QStringLiteral(".xml"))) ==
+                KMessageBox::No) {
                 return;
             }
 
@@ -533,20 +524,21 @@ void CollapsibleEffectView::slotSaveEffect()
         effect.removeAttribute(QStringLiteral("kdenlive_ix"));
         QString namedId = name;
         QString sourceId = effect.attribute("id");
-        // When saving an effect as custom, it might be necessary to keep track of the original 
+        // When saving an effect as custom, it might be necessary to keep track of the original
         // effect id as it is sometimes used in Kdenlive to trigger special behaviors
         if (sourceId.startsWith(QStringLiteral("fade_to_"))) {
             namedId.prepend(QStringLiteral("fade_to_"));
         } else if (sourceId.startsWith(QStringLiteral("fade_from_"))) {
             namedId.prepend(QStringLiteral("fade_from_"));
-        } if (sourceId.startsWith(QStringLiteral("fadein"))) {
+        }
+        if (sourceId.startsWith(QStringLiteral("fadein"))) {
             namedId.prepend(QStringLiteral("fadein_"));
-        } if (sourceId.startsWith(QStringLiteral("fadeout"))) {
+        }
+        if (sourceId.startsWith(QStringLiteral("fadeout"))) {
             namedId.prepend(QStringLiteral("fadeout_"));
         }
         effect.setAttribute(QStringLiteral("id"), namedId);
-        QString masterType = effect.attribute(QLatin1String("type"));
-        effect.setAttribute(QStringLiteral("type"), (masterType == QLatin1String("audio") || masterType == QLatin1String("customAudio")) ? QStringLiteral("customAudio") : QStringLiteral("customVideo"));
+        effect.setAttribute(QStringLiteral("type"), m_model->isAudio() ? QStringLiteral("customAudio") : QStringLiteral("customVideo"));
 
         QDomElement effectname = effect.firstChildElement(QStringLiteral("name"));
         effect.removeChild(effectname);
@@ -559,18 +551,20 @@ void CollapsibleEffectView::slotSaveEffect()
         effectprops.setAttribute(QStringLiteral("type"), QStringLiteral("custom"));
         QFile file(dir.absoluteFilePath(name + QStringLiteral(".xml")));
 
-        if(!enteredDescription.trimmed().isEmpty()){
-                    QDomElement root = doc.documentElement();
-                    QDomElement nodelist = root.firstChildElement("description");
-                    QDomElement newNodeTag = doc.createElement(QString("description"));
-                    QDomText text = doc.createTextNode(enteredDescription);
-                    newNodeTag.appendChild(text);
-                    root.replaceChild(newNodeTag, nodelist);
+        if (!enteredDescription.trimmed().isEmpty()) {
+            QDomElement root = doc.documentElement();
+            QDomElement nodelist = root.firstChildElement("description");
+            QDomElement newNodeTag = doc.createElement(QString("description"));
+            QDomText text = doc.createTextNode(enteredDescription);
+            newNodeTag.appendChild(text);
+            root.replaceChild(newNodeTag, nodelist);
         }
 
         if (file.open(QFile::WriteOnly | QFile::Truncate)) {
             QTextStream out(&file);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             out.setCodec("UTF-8");
+#endif
             out << doc.toString();
         }
         file.close();
@@ -578,7 +572,6 @@ void CollapsibleEffectView::slotSaveEffect()
     }
 }
 
-
 QDomDocument CollapsibleEffectView::toXml() const
 {
     QDomDocument doc;
@@ -607,7 +600,6 @@ void CollapsibleEffectView::slotResetEffect()
     m_view->resetValues();
 }
 
-
 void CollapsibleEffectView::updateHeight()
 {
     if (m_view->height() == widgetFrame->height()) {
@@ -628,8 +620,8 @@ void CollapsibleEffectView::switchCollapsed(int row)
 void CollapsibleEffectView::slotSwitch(bool collapse)
 {
     widgetFrame->setFixedHeight(collapse ? 0 : m_view->height());
-    zoneFrame->setFixedHeight(collapse || !m_inOutButton->isChecked() ? 0 :frame->height());
-    setFixedHeight(widgetFrame->height() + frame->minimumHeight() + zoneFrame->height()+ 2 * (contentsMargins().top() + decoframe->lineWidth()));
+    zoneFrame->setFixedHeight(collapse || !m_inOutButton->isChecked() ? 0 : frame->height());
+    setFixedHeight(widgetFrame->height() + frame->minimumHeight() + zoneFrame->height() + 2 * (contentsMargins().top() + decoframe->lineWidth()));
     m_model->setCollapsed(collapse);
     emit switchHeight(m_model, height());
 }
@@ -646,7 +638,8 @@ void CollapsibleEffectView::setGroupIndex(int ix)
     m_effect.setAttribute(QStringLiteral("kdenlive_info"), m_info.toString());*/
 }
 
-void CollapsibleEffectView::setGroupName(const QString &groupName){
+void CollapsibleEffectView::setGroupName(const QString &groupName)
+{
     Q_UNUSED(groupName)
     /*m_info.groupName = groupName;
     m_effect.setAttribute(QStringLiteral("kdenlive_info"), m_info.toString());*/
@@ -768,11 +761,7 @@ void CollapsibleEffectView::importKeyframes(const QString &kf)
 {
     QMap<QString, QString> keyframes;
     if (kf.contains(QLatin1Char('\n'))) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        const QStringList params = kf.split(QLatin1Char('\n'), QString::SkipEmptyParts);
-#else
         const QStringList params = kf.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
-#endif
         for (const QString &param : params) {
             keyframes.insert(param.section(QLatin1Char('='), 0, 0), param.section(QLatin1Char('='), 1));
         }
@@ -885,6 +874,27 @@ void CollapsibleEffectView::enableView(bool enabled)
 void CollapsibleEffectView::blockWheelEvent(bool block)
 {
     m_blockWheel = block;
+    Qt::FocusPolicy policy = block ? Qt::StrongFocus : Qt::WheelFocus;
+    foreach (QSpinBox *sp, findChildren<QSpinBox *>()) {
+        sp->installEventFilter(this);
+        sp->setFocusPolicy(policy);
+    }
+    foreach (QComboBox *cb, findChildren<QComboBox *>()) {
+        cb->installEventFilter(this);
+        cb->setFocusPolicy(policy);
+    }
+    foreach (QProgressBar *cb, findChildren<QProgressBar *>()) {
+        cb->installEventFilter(this);
+        cb->setFocusPolicy(policy);
+    }
+    foreach (WheelContainer *cb, findChildren<WheelContainer *>()) {
+        cb->installEventFilter(this);
+        cb->setFocusPolicy(policy);
+    }
+    foreach (QDoubleSpinBox *cb, findChildren<QDoubleSpinBox *>()) {
+        cb->installEventFilter(this);
+        cb->setFocusPolicy(policy);
+    }
 }
 
 void CollapsibleEffectView::switchInOut(bool checked)
@@ -897,29 +907,27 @@ void CollapsibleEffectView::switchInOut(bool checked)
     if (inOut.first == inOut.second || !checked) {
         ObjectId owner = m_model->getOwnerId();
         switch (owner.first) {
-            case ObjectType::TimelineClip:
-            {
-                int in = pCore->getItemIn(owner);
-                inOut = {in, in + pCore->getItemDuration(owner)};
-                break;
+        case ObjectType::TimelineClip: {
+            int in = pCore->getItemIn(owner);
+            inOut = {in, in + pCore->getItemDuration(owner)};
+            break;
+        }
+        case ObjectType::TimelineTrack:
+        case ObjectType::Master: {
+            if (!checked) {
+                inOut = {0, 0};
+            } else {
+                int in = pCore->getTimelinePosition();
+                inOut = {in, in + pCore->getDurationFromString(KdenliveSettings::transition_duration())};
             }
-            case ObjectType::TimelineTrack:
-            case ObjectType::Master:
-            {
-                if (!checked) {
-                    inOut = {0,0};
-                } else {
-                    int in = pCore->getTimelinePosition();
-                    inOut = {in, in + pCore->getDurationFromString(KdenliveSettings::transition_duration())};
-                }
-                break;
-            }
-            default:
-                qDebug()<<"== UNSUPPORTED ITEM TYPE FOR EFFECT RANGE: "<<int(owner.first);
-                break;
+            break;
+        }
+        default:
+            qDebug() << "== UNSUPPORTED ITEM TYPE FOR EFFECT RANGE: " << int(owner.first);
+            break;
         }
     }
-    qDebug()<<"==== SWITCHING IN / OUT: "<<inOut.first<<"-"<<inOut.second;
+    qDebug() << "==== SWITCHING IN / OUT: " << inOut.first << "-" << inOut.second;
     if (inOut.first > -1) {
         m_model->setInOut(effectName, inOut, checked, true);
         m_inPos->setValue(inOut.first);
@@ -930,7 +938,7 @@ void CollapsibleEffectView::switchInOut(bool checked)
 void CollapsibleEffectView::updateInOut(QPair<int, int> inOut, bool withUndo)
 {
     if (!m_inOutButton->isChecked()) {
-        qDebug()<<"=== CANNOT UPDATE ZONE ON EFFECT!!!";
+        qDebug() << "=== CANNOT UPDATE ZONE ON EFFECT!!!";
         return;
     }
     QString effectId = m_model->getAssetId();
@@ -964,4 +972,3 @@ void CollapsibleEffectView::addRemoveKeyframe()
 {
     emit m_view->addRemoveKeyframe();
 }
-
