@@ -3,8 +3,7 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef COLLAPSIBLEEFFECTVIEW_H
-#define COLLAPSIBLEEFFECTVIEW_H
+#pragma once
 
 #include "abstractcollapsiblewidget.h"
 #include "definitions.h"
@@ -159,8 +158,6 @@ signals:
     void switchHeight(std::shared_ptr<EffectItemModel> model, int height);
     void startDrag(QPixmap, std::shared_ptr<EffectItemModel> effectModel);
     void activateEffect(int row);
-    void showEffectZone(ObjectId id, QPair <int, int>inOut, bool checked);
+    void showEffectZone(ObjectId id, QPair<int, int> inOut, bool checked);
     void refresh();
 };
-
-#endif
