@@ -5,8 +5,7 @@ This file is part of Kdenlive. See www.kdenlive.org.
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef CLIPPROPERTIESCONTROLLER_H
-#define CLIPPROPERTIESCONTROLLER_H
+#pragma once
 
 #include "definitions.h"
 #include "utils/timecode.h"
@@ -54,7 +53,11 @@ public:
     explicit AnalysisTree(QWidget *parent = nullptr);
 
 protected:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QMimeData *mimeData(const QList<QTreeWidgetItem *> &list) const override;
+#else
     QMimeData *mimeData(const QList<QTreeWidgetItem *> list) const override;
+#endif
 };
 
 /** @class ClipPropertiesController
@@ -156,5 +159,3 @@ signals:
     void deleteProxy();
     void enableProxy(bool);
 };
-
-#endif
