@@ -4,8 +4,7 @@
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef MONITOR_H
-#define MONITOR_H
+#pragma once
 
 #include "abstractmonitor.h"
 #include "bin/model/markerlistmodel.hpp"
@@ -144,6 +143,9 @@ public:
     void focusTimecode();
     /** @brief Ensure the video widget has focus to make keyboard shortcuts work */
     void fixFocus();
+    /** @brief Show a rec countdown over the monitor **/
+    void startCountDown();
+    void stopCountDown();
 
 protected:
     void mousePressEvent(QMouseEvent *event) override;
@@ -211,6 +213,7 @@ private:
     int m_forceSizeFactor;
     int m_offset;
     MonitorSceneType m_lastMonitorSceneType;
+    bool m_displayingCountdown;
     MonitorAudioLevel *m_audioMeterWidget;
     QTimer m_droppedTimer;
     double m_displayedFps;
@@ -374,5 +377,3 @@ signals:
     void activateTrack(int, bool notesMode = false);
     void autoKeyframeChanged();
 };
-
-#endif
