@@ -5,8 +5,7 @@
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef CLIPSTABILIZE_H
-#define CLIPSTABILIZE_H
+#pragma once
 
 #include "definitions.h"
 #include "utils/timecode.h"
@@ -51,5 +50,3 @@ private:
 signals:
     void addClip(const QUrl &url);
 };
-
-#endif
