@@ -18,6 +18,8 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "project/dialogs/projectsettings.h"
 #include "utils/thumbnailcache.hpp"
 #include "xml/xml.hpp"
+#include <audiomixer/mixermanager.hpp>
+#include <lib/localeHandling.h>
 
 // Temporary for testing
 #include "bin/model/markerlistmodel.hpp"
@@ -29,26 +31,30 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "timeline2/view/timelinewidget.h"
 
 #include <KActionCollection>
+#include <KConfigGroup>
 #include <KJob>
+#include <KJobWidgets>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KRecentDirs>
 #include <kcoreaddons_version.h>
-#include <klocalizedstring.h>
 
 #include "kdenlive_debug.h"
-#include <KConfigGroup>
 #include <QAction>
 #include <QCryptographicHash>
 #include <QFileDialog>
+#include <QJsonArray>
+#include <QJsonDocument>
+#include <QJsonObject>
 #include <QLocale>
 #include <QMimeDatabase>
 #include <QMimeType>
 #include <QProgressDialog>
+#include <QSaveFile>
 #include <QTimeZone>
-#include <audiomixer/mixermanager.hpp>
-#include <lib/localeHandling.h>
 
-static QString getProjectNameFilters(bool ark=true) {
+static QString getProjectNameFilters(bool ark = true)
+{
     auto filter = i18n("Kdenlive Project (*.kdenlive)");
     if (ark) {
         filter.append(";;" + i18n("Archived Project (*.tar.gz *.zip)"));
@@ -56,7 +62,6 @@ static QString getProjectNameFilters(bool ark=true) {
     return filter;
 }
 
-
 ProjectManager::ProjectManager(QObject *parent)
     : QObject(parent)
     , m_mainTimelineModel(nullptr)
@@ -75,7 +80,7 @@ ProjectManager::ProjectManager(QObject *parent)
 
     QAction *saveCopyAction = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")), i18n("Save Copy…"), this);
     pCore->window()->addAction(QStringLiteral("file_save_copy"), saveCopyAction);
-    connect(saveCopyAction,  &QAction::triggered, this, [this]{ saveFileAs(true); });
+    connect(saveCopyAction, &QAction::triggered, this, [this] { saveFileAs(true); });
 
     QAction *backupAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-undo")), i18n("Open Backup File…"), this);
     pCore->window()->addAction(QStringLiteral("open_backup"), backupAction);
@@ -181,7 +186,8 @@ void ProjectManager::newFile(QString profileName, bool showProjectSettings)
             documentProperties.insert(QStringLiteral("storagefolder"), folder.absoluteFilePath(documentId));
         }
     } else {
-        QPointer<ProjectSettings> w = new ProjectSettings(nullptr, QMap<QString, QString>(), QStringList(), projectTracks.first, projectTracks.second, audioChannels, KdenliveSettings::defaultprojectfolder(), false, true, pCore->window());
+        QPointer<ProjectSettings> w = new ProjectSettings(nullptr, QMap<QString, QString>(), QStringList(), projectTracks.first, projectTracks.second,
+                                                          audioChannels, KdenliveSettings::defaultprojectfolder(), false, true, pCore->window());
         connect(w.data(), &ProjectSettings::refreshProfiles, pCore->window(), &MainWindow::slotRefreshProfiles);
         if (w->exec() != QDialog::Accepted) {
             delete w;
@@ -224,10 +230,9 @@ void ProjectManager::newFile(QString profileName, bool showProjectSettings)
         documentMetadata = w->metadata();
         delete w;
     }
-    bool openBackup;
     m_notesPlugin->clear();
     pCore->bin()->cleanDocument();
-    KdenliveDoc *doc = new KdenliveDoc(QUrl(), projectFolder, pCore->window()->m_commandStack, profileName, documentProperties, documentMetadata, projectTracks, audioChannels, &openBackup, pCore->window());
+    KdenliveDoc *doc = new KdenliveDoc(projectFolder, pCore->window()->m_commandStack, profileName, documentProperties, documentMetadata, projectTracks, audioChannels, pCore->window());
     doc->m_autosave = new KAutoSaveFile(startFile, doc);
     doc->m_sameProjectFolder = sameProjectFolder;
     ThumbnailCache::get()->clearCache();
@@ -259,22 +264,21 @@ void ProjectManager::testSetActiveDocument(KdenliveDoc *doc, std::shared_ptr<Tim
 bool ProjectManager::testSaveFileAs(const QString &outputFileName)
 {
     QString saveFolder = QFileInfo(outputFileName).absolutePath();
-    QMap<QString,QString>docProperties;
+    QMap<QString, QString> docProperties;
     docProperties.insert(QStringLiteral("version"), QString::number(m_project->getDocumentVersion()));
     docProperties.insert(QStringLiteral("timelineHash"), m_mainTimelineModel->timelineHash().toHex());
-    pCore->projectItemModel()->saveDocumentProperties(docProperties, QMap<QString,QString>(),
-                                                      m_project->getGuideModel());
+    pCore->projectItemModel()->saveDocumentProperties(docProperties, QMap<QString, QString>(), m_project->getGuideModel());
     QString scene = m_mainTimelineModel->sceneList(saveFolder);
-    
+
     QSaveFile file(outputFileName);
     if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {
-        qDebug()<<"//////  ERROR writing to file: " << outputFileName;
+        qDebug() << "//////  ERROR writing to file: " << outputFileName;
         return false;
     }
 
     file.write(scene.toUtf8());
     if (!file.commit()) {
-        qDebug()<<"Cannot write to file %1";
+        qDebug() << "Cannot write to file %1";
         return false;
     }
     return true;
@@ -334,10 +338,9 @@ bool ProjectManager::closeCurrentDocument(bool saveChanges, bool quit)
 bool ProjectManager::saveFileAs(const QString &outputFileName, bool saveACopy)
 {
     pCore->monitorManager()->pauseActiveMonitor();
-    QString oldProjectFolder = m_project->url().isEmpty()
-            ? QString()
-            : QFileInfo(m_project->url().toLocalFile()).absolutePath() + QStringLiteral("/cachefiles");
-            // this was the old project folder in case the "save in project file location" setting was active
+    QString oldProjectFolder =
+        m_project->url().isEmpty() ? QString() : QFileInfo(m_project->url().toLocalFile()).absolutePath() + QStringLiteral("/cachefiles");
+    // this was the old project folder in case the "save in project file location" setting was active
 
     // Sync document properties
     if (!saveACopy && outputFileName != m_project->url().toLocalFile()) {
@@ -360,7 +363,14 @@ bool ProjectManager::saveFileAs(const QString &outputFileName, bool saveACopy)
     }
     QUrl url = QUrl::fromLocalFile(outputFileName);
     // Save timeline thumbnails
-    QStringList thumbKeys = pCore->window()->getMainTimeline()->controller()->getThumbKeys();
+    std::unordered_map<QString, std::vector<int>> thumbKeys = pCore->window()->getMainTimeline()->controller()->getThumbKeys();
+    pCore->projectItemModel()->updateCacheThumbnail(thumbKeys);
+    // Remove duplicates
+    for (auto p : thumbKeys) {
+        std::sort(p.second.begin(), p.second.end());
+        auto last = std::unique(p.second.begin(), p.second.end());
+        p.second.erase(last, p.second.end());
+    }
     ThumbnailCache::get()->saveCachedThumbs(thumbKeys);
     if (!saveACopy) {
         m_project->setUrl(url);
@@ -381,6 +391,7 @@ bool ProjectManager::saveFileAs(const QString &outputFileName, bool saveACopy)
         pCore->window()->setWindowTitle(m_project->description());
         m_project->setModified(false);
     }
+
     m_recentFilesAction->addUrl(url);
     // remember folder for next project opening
     KRecentDirs::add(QStringLiteral(":KdenliveProjectsFolder"), saveFolder);
@@ -389,11 +400,12 @@ bool ProjectManager::saveFileAs(const QString &outputFileName, bool saveACopy)
         m_fileRevert->setEnabled(true);
         pCore->window()->m_undoView->stack()->setClean();
         QString newProjectFolder(saveFolder + QStringLiteral("/cachefiles"));
-        if(((oldProjectFolder.isEmpty() && m_project->m_sameProjectFolder) || m_project->projectTempFolder() == oldProjectFolder) && newProjectFolder != m_project->projectTempFolder()) {
+        if (((oldProjectFolder.isEmpty() && m_project->m_sameProjectFolder) || m_project->projectTempFolder() == oldProjectFolder) &&
+            newProjectFolder != m_project->projectTempFolder()) {
             KMessageBox::ButtonCode answer = KMessageBox::warningContinueCancel(
                 pCore->window(), i18n("The location of the project file changed. You selected to use the location of the project file to save temporary files. "
-                           "This will move all temporary files from <b>%1</b> to <b>%2</b>, the project file will then be reloaded",
-                           m_project->projectTempFolder(), newProjectFolder));
+                                      "This will move all temporary files from <b>%1</b> to <b>%2</b>, the project file will then be reloaded",
+                                      m_project->projectTempFolder(), newProjectFolder));
 
             if (answer == KMessageBox::Continue) {
                 // Proceed with move
@@ -406,16 +418,16 @@ bool ProjectManager::saveFileAs(const QString &outputFileName, bool saveACopy)
                     QDir newDir(newProjectFolder);
                     QDir oldDir(m_project->projectTempFolder());
                     if (newDir.exists(documentId)) {
-                        KMessageBox::sorry(pCore->window(), i18n("Cannot perform operation, target directory already exists: %1", newDir.absoluteFilePath(documentId)));
+                        KMessageBox::sorry(pCore->window(),
+                                           i18n("Cannot perform operation, target directory already exists: %1", newDir.absoluteFilePath(documentId)));
                     } else {
                         // Proceed with the move
-                        pCore->projectManager()->moveProjectData(oldDir.absoluteFilePath(documentId), newDir.absolutePath());
+                        moveProjectData(oldDir.absoluteFilePath(documentId), newDir.absolutePath());
                     }
                 }
             }
         }
     }
-
     return true;
 }
 
@@ -440,7 +452,7 @@ bool ProjectManager::saveFileAs(bool saveACopy)
     if (fd.exec() != QDialog::Accepted || fd.selectedFiles().isEmpty()) {
         return false;
     }
-    
+
     QString outputFile = fd.selectedFiles().constFirst();
 
     bool ok = false;
@@ -531,8 +543,8 @@ bool ProjectManager::checkForBackupFile(const QUrl &url, bool newFile)
     }
 
     if (orphanedFile) {
-        if (KMessageBox::questionYesNo(nullptr, i18n("Auto-saved file exist. Do you want to recover now?"), i18n("File Recovery"),
-                                       KGuiItem(i18n("Recover")), KGuiItem(i18n("Do not recover"))) == KMessageBox::Yes) {
+        if (KMessageBox::questionYesNo(nullptr, i18n("Auto-saved file exist. Do you want to recover now?"), i18n("File Recovery"), KGuiItem(i18n("Recover")),
+                                       KGuiItem(i18n("Do not recover"))) == KMessageBox::Yes) {
             doOpenFile(url, orphanedFile);
             return true;
         }
@@ -588,7 +600,7 @@ void ProjectManager::openFile(const QUrl &url)
     doOpenFile(url, nullptr);
 }
 
-void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
+void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale, bool isBackup)
 {
     Q_ASSERT(m_project == nullptr);
     m_fileRevert->setEnabled(true);
@@ -606,19 +618,54 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
         m_progressDialog->setMaximum(0);
         m_progressDialog->show();
     }
-    bool openBackup;
     m_notesPlugin->clear();
-    int audioChannels = 2;
-    if (KdenliveSettings::audio_channels() == 1) {
-        audioChannels = 4;
-    } else if (KdenliveSettings::audio_channels() == 2) {
-        audioChannels = 6;
+
+    DocOpenResult openResult = KdenliveDoc::Open(stale ? QUrl::fromLocalFile(stale->fileName()) : url,
+        QString(), pCore->window()->m_commandStack, false, pCore->window());
+
+    KdenliveDoc *doc;
+    if (!openResult.isSuccessful()) {
+        if (!isBackup) {
+            int answer = KMessageBox::warningYesNoCancel(
+                        pCore->window(), i18n("Cannot open the project file. Error:\n%1\nDo you want to open a backup file?", openResult.getError()),
+                        i18n("Error opening file"), KGuiItem(i18n("Open Backup")), KGuiItem(i18n("Recover")));
+            if (answer == KMessageBox::ButtonCode::Yes) { // Open Backup
+                slotOpenBackup(url);
+            } else if (answer == KMessageBox::ButtonCode::No) { // Recover
+                // if file was broken by Kdenlive 0.9.4, we can try recovering it. If successful, continue through rest of this function.
+                openResult = KdenliveDoc::Open(stale ? QUrl::fromLocalFile(stale->fileName()) : url,
+                    QString(), pCore->window()->m_commandStack, true, pCore->window());
+                if (openResult.isSuccessful()) {
+                    doc = openResult.getDocument().release();
+                    doc->requestBackup();
+                } else {
+                    KMessageBox::error(pCore->window(), "Could not recover corrupted file.");
+                }
+            }
+        } else {
+            KMessageBox::detailedSorry(pCore->window(), "Could not open the backup project file.", openResult.getError());
+        }
+    } else {
+         doc = openResult.getDocument().release();
     }
 
-    KdenliveDoc *doc = new KdenliveDoc(stale ? QUrl::fromLocalFile(stale->fileName()) : url, QString(), pCore->window()->m_commandStack,
-                                       KdenliveSettings::default_profile().isEmpty() ? pCore->getCurrentProfile()->path() : KdenliveSettings::default_profile(),
-                                       QMap<QString, QString>(), QMap<QString, QString>(),
-                                       {KdenliveSettings::videotracks(), KdenliveSettings::audiotracks()}, audioChannels, &openBackup, pCore->window());
+    // if we could not open the file, and could not recover (or user declined), stop now
+    if (!openResult.isSuccessful()) {
+        delete m_progressDialog;
+        m_progressDialog = nullptr;
+        return;
+    }
+
+    if (openResult.wasUpgraded()) {
+        pCore->displayMessage(i18n("Your project was upgraded, a backup will be created on next save"),
+            ErrorMessage);
+    } else if (openResult.wasModified()) {
+        pCore->displayMessage(i18n("Your project was modified on opening, a backup will be created on next save"),
+            ErrorMessage);
+    }
+    pCore->displayMessage(QString(), OperationCompletedMessage);
+
+
     if (stale == nullptr) {
         const QString projectId = QCryptographicHash::hash(url.fileName().toUtf8(), QCryptographicHash::Md5).toHex();
         QUrl autosaveUrl = QUrl::fromLocalFile(QFileInfo(url.path()).absoluteDir().absoluteFilePath(projectId + QStringLiteral(".kdenlive")));
@@ -651,7 +698,9 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
     m_project = doc;
     m_project->loadDocumentGuides();
     QDateTime documentDate = QFileInfo(m_project->url().toLocalFile()).lastModified();
-    if (!updateTimeline(m_project->getDocumentProperty(QStringLiteral("position")).toInt(), m_project->getDocumentProperty(QStringLiteral("previewchunks")), m_project->getDocumentProperty(QStringLiteral("dirtypreviewchunks")), documentDate, m_project->getDocumentProperty(QStringLiteral("disablepreview")).toInt())) {
+    if (!updateTimeline(m_project->getDocumentProperty(QStringLiteral("position")).toInt(), m_project->getDocumentProperty(QStringLiteral("previewchunks")),
+                        m_project->getDocumentProperty(QStringLiteral("dirtypreviewchunks")), documentDate,
+                        m_project->getDocumentProperty(QStringLiteral("disablepreview")).toInt())) {
         delete m_progressDialog;
         m_progressDialog = nullptr;
         return;
@@ -661,9 +710,6 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
     m_mainTimelineModel->updateFieldOrderFilter(pCore->getCurrentProfile());
     emit docOpened(m_project);
     pCore->displayMessage(QString(), OperationCompletedMessage, 100);
-    if (openBackup) {
-        slotOpenBackup(url);
-    }
     m_lastSave.start();
     delete m_progressDialog;
     m_progressDialog = nullptr;
@@ -698,7 +744,7 @@ bool ProjectManager::slotOpenBackup(const QUrl &url)
         projectFolder = QUrl::fromLocalFile(KdenliveSettings::defaultprojectfolder());
         projectFile = url;
     } else {
-        projectFolder = QUrl::fromLocalFile(m_project->projectTempFolder());
+        projectFolder = QUrl::fromLocalFile(m_project ? m_project->projectTempFolder() : QString());
         projectFile = m_project->url();
         projectId = m_project->getDocumentProperty(QStringLiteral("documentid"));
     }
@@ -708,7 +754,7 @@ bool ProjectManager::slotOpenBackup(const QUrl &url)
         QString requestedBackup = dia->selectedFile();
         m_project->backupLastSavedVersion(projectFile.toLocalFile());
         closeCurrentDocument(false);
-        doOpenFile(QUrl::fromLocalFile(requestedBackup), nullptr);
+        doOpenFile(QUrl::fromLocalFile(requestedBackup), nullptr, true);
         if (m_project) {
             if (!m_project->url().isEmpty()) {
                 // Only update if restore succeeded
@@ -934,13 +980,12 @@ void ProjectManager::moveProjectData(const QString &src, const QString &dest)
 {
     // Move tmp folder (thumbnails, timeline preview)
     m_project->moveProjectData(src, dest);
-    KIO::CopyJob *copyJob = KIO::move(QUrl::fromLocalFile(src), QUrl::fromLocalFile(dest));
+    KIO::CopyJob *copyJob = KIO::move(QUrl::fromLocalFile(src), QUrl::fromLocalFile(dest), KIO::DefaultFlags);
+    if (copyJob->uiDelegate()) {
+        KJobWidgets::setWindow(copyJob, pCore->window());
+    }
     connect(copyJob, &KJob::result, this, &ProjectManager::slotMoveFinished);
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5,80,0)
-    connect(copyJob, SIGNAL(percent(KJob*,ulong)), this, SLOT(slotMoveProgress(KJob*,ulong)));
-#else
     connect(copyJob, &KJob::percentChanged, this, &ProjectManager::slotMoveProgress);
-#endif
 }
 
 void ProjectManager::slotMoveProgress(KJob *, unsigned long progress)
@@ -977,14 +1022,15 @@ bool ProjectManager::updateTimeline(int pos, const QString &chunks, const QStrin
     pCore->window()->getMainTimeline()->loading = true;
     pCore->window()->slotSwitchTimelineZone(m_project->getDocumentProperty(QStringLiteral("enableTimelineZone")).toInt() == 1);
 
-    QScopedPointer<Mlt::Producer> xmlProd(new Mlt::Producer(pCore->getCurrentProfile()->profile(), "xml-string",
-                                                            m_project->getAndClearProjectXml().constData()));
+    QScopedPointer<Mlt::Producer> xmlProd(
+        new Mlt::Producer(pCore->getCurrentProfile()->profile(), "xml-string", m_project->getAndClearProjectXml().constData()));
 
     Mlt::Service s(*xmlProd);
     Mlt::Tractor tractor(s);
     if (tractor.count() == 0) {
         // Wow we have a project file with empty tractor, probably corrupted, propose to open a recovery file
-        KMessageBox::ButtonCode res = KMessageBox::warningContinueCancel(qApp->activeWindow(), i18n("Project file is corrupted (no tracks). Try to find a backup file?"));
+        KMessageBox::ButtonCode res =
+            KMessageBox::warningContinueCancel(qApp->activeWindow(), i18n("Project file is corrupted (no tracks). Try to find a backup file?"));
         pCore->window()->getMainTimeline()->loading = false;
         m_project->setModified(false);
         if (res == KMessageBox::Continue) {
@@ -1003,23 +1049,19 @@ bool ProjectManager::updateTimeline(int pos, const QString &chunks, const QStrin
     pCore->window()->getMainTimeline()->setModel(m_mainTimelineModel, pCore->monitorManager()->projectMonitor()->getControllerProxy());
     bool projectErrors = false;
     m_project->cleanupTimelinePreview(documentDate);
-    if (!constructTimelineFromMelt(m_mainTimelineModel, tractor, m_progressDialog, m_project->modifiedDecimalPoint(), chunks, dirty, enablePreview, &projectErrors)) {
-        //TODO: act on project load failure
-        qDebug()<<"// Project failed to load!!";
+    if (!constructTimelineFromMelt(m_mainTimelineModel, tractor, m_progressDialog, m_project->modifiedDecimalPoint(), chunks, dirty, enablePreview,
+                                   &projectErrors)) {
+        // TODO: act on project load failure
+        qDebug() << "// Project failed to load!!";
     }
     // Free memory used by original playlist
+    xmlProd->clear();
     xmlProd.reset(nullptr);
     const QString groupsData = m_project->getDocumentProperty(QStringLiteral("groups"));
     // update track compositing
-    int compositing = pCore->currentDoc()->getDocumentProperty(QStringLiteral("compositing"), QStringLiteral("2")).toInt();
-    if (compositing == 1) {
-        // Composite transition is deprecated, switch to hq by default
-        compositing = 2;
-    }
+    bool compositing = pCore->currentDoc()->getDocumentProperty(QStringLiteral("compositing"), QStringLiteral("1")).toInt() > 0;
     emit pCore->currentDoc()->updateCompositionMode(compositing);
-    if (compositing < 2) {
-        pCore->window()->getMainTimeline()->controller()->switchCompositing(compositing);
-    }
+    pCore->window()->getMainTimeline()->controller()->switchCompositing(compositing);
     if (!groupsData.isEmpty()) {
         m_mainTimelineModel->loadGroups(groupsData);
     }
@@ -1028,14 +1070,21 @@ bool ProjectManager::updateTimeline(int pos, const QString &chunks, const QStrin
     pCore->monitorManager()->projectMonitor()->slotActivateMonitor();
     pCore->monitorManager()->projectMonitor()->setProducer(m_mainTimelineModel->producer(), pos);
     pCore->monitorManager()->projectMonitor()->adjustRulerSize(m_mainTimelineModel->duration() - 1, m_project->getGuideModel());
+    pCore->window()->slotUpdateProjectDuration(m_mainTimelineModel->duration() - 1);
     pCore->window()->getMainTimeline()->controller()->setZone(m_project->zone(), false);
     pCore->window()->getMainTimeline()->controller()->setScrollPos(m_project->getDocumentProperty(QStringLiteral("scrollPos")).toInt());
-    int activeTrackPosition = m_project->getDocumentProperty(QStringLiteral("activeTrack"), QString::number( - 1)).toInt();
-    if (activeTrackPosition > -1 && activeTrackPosition < m_mainTimelineModel->getTracksCount()) {
+    int activeTrackPosition = m_project->getDocumentProperty(QStringLiteral("activeTrack"), QString::number(-1)).toInt();
+    if (activeTrackPosition == -2) {
+        // Subtitle model track always has ID == -2
+        pCore->window()->getMainTimeline()->controller()->setActiveTrack(-2);
+    } else if (activeTrackPosition > -1 && activeTrackPosition < m_mainTimelineModel->getTracksCount()) {
+        // otherwise, convert the position to a track ID
         pCore->window()->getMainTimeline()->controller()->setActiveTrack(m_mainTimelineModel->getTrackIndexFromPosition(activeTrackPosition));
     } else {
-        // Subtitle model track was active
-        pCore->window()->getMainTimeline()->controller()->setActiveTrack(activeTrackPosition);
+        qWarning() << "[BUG] \"activeTrack\" property is" << activeTrackPosition <<
+            "but track count is only" << m_mainTimelineModel->getTracksCount();
+        // set it to some valid track instead
+        pCore->window()->getMainTimeline()->controller()->setActiveTrack(m_mainTimelineModel->getTrackIndexFromPosition(0));
     }
     m_mainTimelineModel->setUndoStack(m_project->commandStack());
 
@@ -1049,9 +1098,9 @@ bool ProjectManager::updateTimeline(int pos, const QString &chunks, const QStrin
     return true;
 }
 
-void ProjectManager::adjustProjectDuration()
+void ProjectManager::adjustProjectDuration(int duration)
 {
-    pCore->monitorManager()->projectMonitor()->adjustRulerSize(m_mainTimelineModel->duration() - 1, nullptr);
+    pCore->monitorManager()->projectMonitor()->adjustRulerSize(duration - 1, nullptr);
 }
 
 void ProjectManager::activateAsset(const QVariantMap &effectData)
@@ -1114,7 +1163,7 @@ void ProjectManager::saveWithUpdatedProfile(const QString &updatedProfile)
     QString convertedFile = currentFile.section(QLatin1Char('.'), 0, -2);
     double fpsRatio = newProfile->fps() / pCore->getCurrentFps();
     convertedFile.append(QString("-%1.kdenlive").arg(int(newProfile->fps() * 100)));
-    QString saveFolder = m_project->url().adjusted(QUrl::RemoveFilename |   QUrl::StripTrailingSlash).toLocalFile();
+    QString saveFolder = m_project->url().adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toLocalFile();
     QTemporaryFile tmpFile(saveFolder + "/kdenlive-XXXXXX.mlt");
     if (saveInTempFile) {
         // Save current playlist in tmp file
@@ -1217,7 +1266,8 @@ void ProjectManager::saveWithUpdatedProfile(const QString &updatedProfile)
         }
     }
     if (QFile::exists(convertedFile)) {
-        if (KMessageBox::warningYesNo(qApp->activeWindow(), i18n("Output file %1 already exists.\nDo you want to overwrite it?", convertedFile)) != KMessageBox::Yes) {
+        if (KMessageBox::warningYesNo(qApp->activeWindow(), i18n("Output file %1 already exists.\nDo you want to overwrite it?", convertedFile)) !=
+            KMessageBox::Yes) {
             return;
         }
     }
@@ -1226,7 +1276,9 @@ void ProjectManager::saveWithUpdatedProfile(const QString &updatedProfile)
         return;
     }
     QTextStream out(&file);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     out.setCodec("UTF-8");
+#endif
     out << doc.toString();
     if (file.error() != QFile::NoError) {
         KMessageBox::error(qApp->activeWindow(), i18n("Cannot write to file %1", convertedFile));
