@@ -3,8 +3,7 @@ SPDX-FileCopyrightText: 2014 Till Theato <root@ttill.de>
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef PROJECTMANAGER_H
-#define PROJECTMANAGER_H
+#pragma once
 
 #include "kdenlivecore_export.h"
 #include <KRecentFilesAction>
@@ -52,10 +51,10 @@ public:
     /** @brief Store command line args for later opening. */
     void init(const QUrl &projectUrl, const QString &clipList);
 
-    void doOpenFile(const QUrl &url, KAutoSaveFile *stale);
+    void doOpenFile(const QUrl &url, KAutoSaveFile *stale, bool isBackup = false);
     KRecentFilesAction *recentFilesAction();
     void prepareSave();
-    /** @brief Disable all bin effects in current project 
+    /** @brief Disable all bin effects in current project
      *  @param disable if true, all project bin effects will be disabled
      *  @param refreshMonitor if false, monitors will not be refreshed
      */
@@ -175,8 +174,8 @@ public slots:
     void activateAsset(const QVariantMap &effectData);
     /** @brief insert current timeline timecode in notes widget and focus widget to allow entering quick note */
     void slotAddProjectNote();
-    /** @brief insert license text in notes widget and focus widget to allow entering quick note */
-    void slotAddTextNote(const QString &text);
+    /** @brief insert license text in notes widget and focus widget to allow entering quick note. Virtual to allow Mocking */
+    virtual void slotAddTextNote(const QString &text);
 
 private slots:
     void slotRevert();
@@ -215,5 +214,3 @@ private:
     bool m_loading{false};
     void saveRecentFiles();
 };
-
-#endif
