@@ -6,12 +6,12 @@
 */
 
 #include "renderpresetmodel.hpp"
-#include "renderpresetrepository.hpp"
 #include "core.h"
 #include "kdenlive_debug.h"
 #include "kdenlivesettings.h"
-#include "profiles/profilerepository.hpp"
 #include "profiles/profilemodel.hpp"
+#include "profiles/profilerepository.hpp"
+#include "renderpresetrepository.hpp"
 
 #include <KLocalizedString>
 #include <KMessageWidget>
@@ -31,6 +31,7 @@ RenderPresetModel::RenderPresetModel(QDomElement preset, const QString &presetFi
     , m_renderer(renderer)
     , m_url(preset.attribute(QStringLiteral("url")))
     , m_speeds(preset.attribute(QStringLiteral("speeds")))
+    , m_defaultSpeedIndex(preset.attribute(QStringLiteral("defaultspeedindex"), QStringLiteral("-1")).toInt())
     , m_topFieldFirst(preset.attribute(QStringLiteral("top_field_first")))
 {
     if (m_groupName.isEmpty()) {
@@ -47,6 +48,10 @@ RenderPresetModel::RenderPresetModel(QDomElement preset, const QString &presetFi
         m_params.append(QStringLiteral(" f=%1").arg(m_extension));
     }
 
+    if (m_defaultSpeedIndex < 0) {
+        m_defaultSpeedIndex = (speeds().count() - 1) * 0.75;
+    }
+
     m_vQualities = preset.attribute(QStringLiteral("qualities"));
     m_defaultVQuality = preset.attribute(QStringLiteral("defaultquality"));
     m_vBitrates = preset.attribute(QStringLiteral("bitrates"));
@@ -65,6 +70,7 @@ RenderPresetModel::RenderPresetModel(const QString &groupName, const QString &pa
     , m_params(params)
     , m_groupName(groupName)
     , m_renderer(QStringLiteral("avformat"))
+    , m_defaultSpeedIndex(-1)
 {
     KConfig config(path, KConfig::SimpleConfig);
     KConfigGroup group = config.group(QByteArray());
@@ -92,8 +98,9 @@ RenderPresetModel::RenderPresetModel(const QString &groupName, const QString &pa
     checkPreset();
 }
 
-RenderPresetModel::RenderPresetModel(const QString &name, const QString &groupName, const QString &params, const QString &defaultVBitrate, const QString &defaultVQuality,
-                                       const QString &defaultABitrate, const QString &defaultAQuality, const QString &speeds)
+RenderPresetModel::RenderPresetModel(const QString &name, const QString &groupName, const QString &params, const QString &defaultVBitrate,
+                                     const QString &defaultVQuality, const QString &defaultABitrate, const QString &defaultAQuality,
+                                     const QString &speedsString)
     : m_presetFile()
     , m_editable()
     , m_name(name)
@@ -104,7 +111,7 @@ RenderPresetModel::RenderPresetModel(const QString &name, const QString &groupNa
     , m_groupName(groupName)
     , m_renderer(QStringLiteral("avformat"))
     , m_url()
-    , m_speeds(speeds)
+    , m_speeds(speedsString)
     , m_topFieldFirst()
     , m_vBitrates()
     , m_defaultVBitrate(defaultVBitrate)
@@ -119,10 +126,13 @@ RenderPresetModel::RenderPresetModel(const QString &name, const QString &groupNa
         m_groupName = i18nc("Category Name", "Custom");
     }
 
+    m_defaultSpeedIndex = (speeds().count() - 1) * 0.75;
+
     checkPreset();
 }
 
-void RenderPresetModel::checkPreset() {
+void RenderPresetModel::checkPreset()
+{
     QStringList acodecs = RenderPresetRepository::acodecs();
     QStringList vcodecs = RenderPresetRepository::vcodecs();
     QStringList supportedFormats = RenderPresetRepository::supportedFormats();
@@ -187,7 +197,7 @@ void RenderPresetModel::checkPreset() {
 
     if (hasParam(QStringLiteral("profile"))) {
         m_warnings = i18n("This render preset uses a 'profile' parameter.<br />Unless you know what you are doing you will probably "
-                               "have to change it to 'mlt_profile'.");
+                          "have to change it to 'mlt_profile'.");
         return;
     }
 }
@@ -231,6 +241,9 @@ QDomElement RenderPresetModel::toXml()
     if (!m_speeds.isEmpty()) {
         // profile has a variable speed
         profileElement.setAttribute(QStringLiteral("speeds"), m_speeds);
+        if (m_defaultSpeedIndex > 0) {
+            profileElement.setAttribute(QStringLiteral("defaultspeedindex"), m_defaultSpeedIndex);
+        }
     }
     return doc.documentElement();
 }
@@ -244,21 +257,17 @@ QString RenderPresetModel::params(QStringList removeParams) const
     return params.simplified();
 }
 
-QString RenderPresetModel::extension() const {
+QString RenderPresetModel::extension() const
+{
     if (!m_extension.isEmpty()) {
-            return m_extension;
+        return m_extension;
     }
     return getParam(QStringLiteral("f"));
 };
 
-
 QStringList RenderPresetModel::audioBitrates() const
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    return m_aBitrates.split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
     return m_aBitrates.split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
 }
 
 QString RenderPresetModel::defaultABitrate() const
@@ -269,11 +278,7 @@ QString RenderPresetModel::defaultABitrate() const
 QStringList RenderPresetModel::audioQualities() const
 {
     if (!m_aQualities.isEmpty()) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        return m_aQualities.split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
         return m_aQualities.split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
     } else {
         // ATTENTION: historically qualities are sorted from best to worse for some reason
         QString acodec = getParam(QStringLiteral("acodec")).toLower();
@@ -294,11 +299,7 @@ QString RenderPresetModel::defaultAQuality() const
 
 QStringList RenderPresetModel::videoBitrates() const
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    return m_vBitrates.split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
     return m_vBitrates.split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
 }
 
 QString RenderPresetModel::defaultVBitrate() const
@@ -309,15 +310,12 @@ QString RenderPresetModel::defaultVBitrate() const
 QStringList RenderPresetModel::videoQualities() const
 {
     if (!m_vQualities.isEmpty()) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        return m_vQualities.split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
         return m_vQualities.split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
     } else {
         // ATTENTION: historically qualities are sorted from best to worse for some reason
         QString vcodec = getParam(QStringLiteral("vcodec")).toLower();
-        if (vcodec == "libx265" || vcodec.contains("nvenc") || vcodec.endsWith("_amf") || vcodec.startsWith("libx264") || vcodec.endsWith("_vaapi") || vcodec.endsWith("_qsv")) {
+        if (vcodec == "libx265" || vcodec.contains("nvenc") || vcodec.endsWith("_amf") || vcodec.startsWith("libx264") || vcodec.endsWith("_vaapi") ||
+            vcodec.endsWith("_qsv")) {
             return {"0", "51"};
         } else if (vcodec.startsWith("libvpx") || vcodec.startsWith("libaom-")) {
             return {"0", "63"};
@@ -341,11 +339,7 @@ bool RenderPresetModel::editable() const
 
 QStringList RenderPresetModel::speeds() const
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    return m_speeds.split(QLatin1Char(';'), QString::SkipEmptyParts);
-#else
     return m_speeds.split(QLatin1Char(';'), Qt::SkipEmptyParts);
-#endif
 }
 
 QString RenderPresetModel::getParam(const QString &name) const
@@ -368,13 +362,9 @@ RenderPresetModel::RateControl RenderPresetModel::videoRateControl() const
     QString vbufsize = getParam(QStringLiteral("vbufsize"));
     QString vcodec = getParam(QStringLiteral("vcodec"));
     if (!getParam(QStringLiteral("crf")).isEmpty()) {
-        return !vbufsize.isEmpty()
-                ? (vcodec.endsWith("_ videotoolbox") ? RateControl::Average : RateControl::Quality)
-                : RateControl::Constrained;
+        return !vbufsize.isEmpty() ? (vcodec.endsWith("_ videotoolbox") ? RateControl::Average : RateControl::Quality) : RateControl::Constrained;
     }
-    if (!getParam(QStringLiteral("vq")).isEmpty()
-            || !getParam(QStringLiteral("vglobal_quality")).isEmpty()
-            || !getParam(QStringLiteral("qscale")).isEmpty()) {
+    if (!getParam(QStringLiteral("vq")).isEmpty() || !getParam(QStringLiteral("vglobal_quality")).isEmpty() || !getParam(QStringLiteral("qscale")).isEmpty()) {
         return vbufsize.isEmpty() ? RateControl::Quality : RateControl::Constrained;
     } else if (!vbufsize.isEmpty()) {
         return RateControl::Constant;
@@ -470,8 +460,7 @@ RenderPresetModel::InstallType RenderPresetModel::installType() const
 bool RenderPresetModel::hasFixedSize() const
 {
     // TODO
-    return hasParam(QStringLiteral("s"))
-            || m_params.contains(QLatin1String("%dv_standard"));
+    return hasParam(QStringLiteral("s")) || m_params.contains(QLatin1String("%dv_standard"));
 }
 
 QString RenderPresetModel::error() const
