@@ -4,13 +4,12 @@
     SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef RENDERPRESETMODEL_H
-#define RENDERPRESETMODEL_H
+#pragma once
 
+#include <KLocalizedString>
 #include <QDomElement>
 #include <QString>
 #include <memory>
-#include <KLocalizedString>
 
 #include <mlt++/MltProfile.h>
 
@@ -23,24 +22,14 @@ public:
     RenderPresetModel() = delete;
 
     RenderPresetModel(QDomElement preset, const QString &presetFile, bool editable, const QString &groupName = QString(),
-                       const QString &renderer = QStringLiteral("avformat"));
+                      const QString &renderer = QStringLiteral("avformat"));
     RenderPresetModel(const QString &groupName, const QString &path, QString presetName, const QString &params, bool codecInName);
     RenderPresetModel(const QString &name, const QString &groupName, const QString &params, const QString &defaultVBitrate, const QString &defaultVQuality,
                       const QString &defaultABitrate, const QString &defaultAQuality, const QString &speedsString);
 
-    enum InstallType {
-        BuildIn,
-        Custom,
-        Download
-    };
+    enum InstallType { BuildIn, Custom, Download };
 
-    enum RateControl {
-        Unknown = -1,
-        Average = 0,
-        Constant,
-        Quality,
-        Constrained
-    };
+    enum RateControl { Unknown = -1, Average = 0, Constant, Quality, Constrained };
 
     QDomElement toXml();
 
@@ -78,7 +67,6 @@ public:
     int estimateFileSize(int length);
 
 private:
-
     void checkPreset();
 
     QString m_presetFile;
@@ -106,5 +94,3 @@ private:
     QString m_errors;
     QString m_warnings;
 };
-
-#endif
