@@ -5,8 +5,7 @@
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef AUDIOSPECTRUM_H
-#define AUDIOSPECTRUM_H
+#pragma once
 
 #include "abstractaudioscopewidget.h"
 #include "lib/audio/fftTools.h"
@@ -92,5 +91,3 @@ private:
 private slots:
     void slotResetMaxFreq();
 };
-
-#endif // AUDIOSPECTRUM_H
